.MEMORYMAP
SLOTSIZE $4000
DEFAULTSLOT 0
SLOT 0 $0000
SLOT 1 $4000
.ENDME

.ROMBANKMAP
BANKSTOTAL 2
BANKSIZE $4000
BANKS 2
.ENDRO

.EMPTYFILL $C9                ;ret.
.COMPUTESMSCHECKSUM           ;compute sms checksum for this rom.

;=============================================================================
; Constants
;=============================================================================
.define RAM_START    $C000

;=============================================================================
; PSGMOD variables
;=============================================================================
.define PSGMOD_PATTERN_ADDRESS   RAM_START + 10 ;(word)
.define PSGMOD_SONG_START        RAM_START + 12 ;(word)
.define PSGMOD_SP     $C014 ;(byte)
.define PSGMOD_PATTERN_POSITION  RAM_START + 15 ;(byte)
.define PSGMOD_CURRENT_SPEED     RAM_START + 16 ;(byte)
.define PSGMOD_SPEED_COUNTER     RAM_START + 17 ;(byte)
.define PSGMOD_SOUND_DISABLED    RAM_START + 18 ;(byte)


;
; standard stuff?
;

.BANK 0 SLOT 0
.ORG 0

;
; main
;
    di          ;Disable interrupts.
    im 1        ;Interrupt mode 1.
    ld sp, $DFF0 ;Set stack pointer.

    jp main        ;Jump to the main part of the program.
.db "drHirudo"
vdp_reg:

; Register 0

.db %00000100
.db %10000000

; Register 1

.db %10000000
.db %10000001

; Register 2

.db %11111111
.db %10000010

; Register 5

.db %11111111
.db %10000101

; Register 6

.db %11111011
.db %10000110

; Register 7

.db %00000010
.db %10000111

; Register 8

.db %00000000
.db %10001000

; Register 9

.db %00000000
.db %10001001

; Register 10

.db %00000000
.db %10001010

vdp_registers_end:
vdp_size: .dw vdp_registers_end-vdp_reg

.org $0028           ;WaitTOF(b); subroutine called via rst $28
WaitVBL:             ;b contains the number of vertical blanks to wait.
        in a,($7E)   ;Wait for vertical Blank.
        cp $B0
        jr nz, WaitVBL
        nop
        nop
        nop
        djnz WaitVBL

.org $0038           ;SetSprite(A); Subroutine
SetSprite:           ;SetSprite b number of sprite, c - x d - y.
        ld a,b
        out ($BF), a        ; to the VDP control port.
        ld a, $7f           ; at $7F00 begins my sprite table.
        out ($BF), a
        ld a,d
        out ($BE),a
        ld a,b
        add a,a
        add a,$80
        out ($BF), a        ; to the VDP control port.
        ld a, $7f           ; at $7F00 begins my sprite table.
        out ($BF), a
        ld a,c
        out ($BE),a
        ld a,b
        add a,a
        add a,$81
        out ($BF), a        ; to the VDP control port.
        ld a, $7f           ; at $7F00 begins my sprite table.
        out ($BF), a
        inc b
        ld a,b
        out ($BE),a
        ret

.org $0066         ;Pause handler. Removed because it freezed the machine.
;    ld a,(Pause)
;    cp 0
;    jr z,NoPause
;    sub a
;    ld (Pause),a
    retn
;NoPause:
;    inc a
;    ld (Pause),a
;    jr NoPause

    ; * which starts right here.

main:

    ld hl, vdp_reg

    ld c, $BF

    ld b, vdp_size

    otir

;Clear VRAM

    sub a    ; We output two bytes to the VDP control port
    out ($BF), a    ; to indicate that we want to write to VRAM
    ld a, %01000000    ; and to set the VRAM address pointer to
    out ($BF), a    ; $0000.

    ld bc, $4000    ; The VRAM is 16 Kilobytes in size.

    sub a
vram_clear_loop:
    out ($BE), a
    dec c
    jr nz, vram_clear_loop
    djnz vram_clear_loop

    ;Write to CRAM to set the palette.

    ld hl, black_palette    ; load HL with start address of palette
            ; data.
SetPalette:

	ld b, $20
	ld c, $BE
	sub a
	out ($BF), a
	ld a, $C0
	out ($BF), a
	otir

tile_init:

    ld a, $00
    out ($BF), a
     ld a, $40
     out ($BF), a
    ld hl, Tiles ; Load HL with tiles address.

     ld bc, Tiles_size 

tile_loop:

     ld a, (HL)

     out ($BE), a
     inc hl
     dec c
     jr nz, tile_loop
     djnz tile_loop

.define Screen_address $7800      ;Screen memory+$40(hi)

TitleScreen:
    sub a       ;clear a
    out ($BF),a

     ld a, $78
                
     out ($BF), a        ; Then we output this byte to the VDP

	ld bc, 32*24    ; The VRAM is 16 Kilobytes in size.
	ld hl,Tile_Numbers

Title_loop:
        ld a,(hl)
        out ($BE),a
        inc hl
        ld a,(hl)
        out ($BE),a
        inc hl
	dec c
	jr nz, Title_loop
        djnz Title_loop

	ld a,0
	out ($BF),a

	ld a, $7D
                
	out ($BF), a        ; Then we output this byte to the VDP
	ld b, 32*4    ; The VRAM is 16 Kilobytes in size.
        sub a
Zeroes:
	out ($BE),a
	out ($BE),a
	djnz Zeroes


Sprites:

  ld b,0
  ld iy,Sprites_Move_Table
SetSprites:
	ld c,(iy+0)
	inc iy
	ld d,(iy+0)
	inc iy
	rst $38
        ld a,b
	cp 16
	jp nz, SetSprites

  ld hl, PSGMOD_SONG
  call PSGMOD_INITIATE_NEW_SONG

;Turn on the VDP

     ld a, %11000000         ; set bits 6 and 7
     out ($BF), a
     ld a, %10000001         ; indicates a write to VDP reg. 1
     out ($BF), a

;Wait for button press.

    ;Write to CRAM to set the palette.

	ld hl, palette    ; load HL with start address of palette
            ; data.
	ld b, $20
	ld c, $BE
	sub a
	out ($BF), a
	ld a, $C0
	out ($BF), a
	otir

TitleLoop:
  in a,($7E)   ;Wait for vertical Blank.
  cp $80
  jr nz, TitleLoop
  call PSGMOD_PLAY_NEXT_NOTE      ; play next note
  ld b,0

SetSpritesMovement:
	ld c,(iy+0)
	inc iy
	ld d,(iy+0)
	inc iy
	rst $38
        ld a,b
	cp 16
	jp nz, SetSpritesMovement
        ld a,(iy+0)
        cp 16
        jp nz, TitleLoop
	ld iy,Sprites_Move_Table

GBegin:
	jp TitleLoop
;=============================================================================
; Program end
;=============================================================================

.include "PSGMOD.INC"

SETUP_FRAMES:
  ld a, 0
  ld ($FFFC), a
  ld ($FFFD), a
  ld a, 1
  ld ($FFFE), a
  ld a, 2
  ld ($FFFF), a
  ret

PSGMOD_SONG:
.db 0,2,1,3,4,5,4,5
.db 8,9,8,9,6,7,128,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0,0,0,0,0,0,0,0
.db 0

; Pattern 0:
.dw 2258,4049,15,1295,2265,3825,2265,1295
.dw 2850,3825,2271,1295,2857,3825,2857,1295
.dw 3826,3825,2863,1295,3833,3825,3833,1295
.dw 2258,3825,3839,1295,2265,3825,2265,1295
.dw 2850,2849,2271,1295,2857,2849,2857,1295
.dw 3826,2849,2863,1295,3833,2849,3833,1295
.dw 2258,2545,3839,1295,2265,2545,2265,1295
.dw 2850,3025,2271,1295,2857,3025,2857,1295
.dw 2546,3025,2863,1295,2553,3025,2553,1295
.dw 3026,3025,2559,1295,3033,3025,3033,1295
.dw 3826,3025,3039,1295,3833,3025,3833,1295
.dw 2546,3025,3839,1295,2553,3025,2553,1295
.dw 3026,3025,2559,1295,3033,3025,3033,1295
.dw 3826,3025,3039,1295,3833,3025,3833,1295
.dw 2546,3025,3839,1295,2553,3025,2553,1295
.dw 2258,3025,2559,1295,2265,3025,2265,1295
.dw 2146,3601,2271,1295,2153,3393,2153,1295
.dw 2546,3393,2159,1295,2553,3393,2553,1295
.dw 3394,3393,2559,1295,3401,3393,3401,1295
.dw 2146,3393,3407,1295,2153,3393,2153,1295
.dw 2546,2145,2159,1295,2553,2145,2553,1295
.dw 3394,2145,2559,1295,3401,2145,3401,1295
.dw 2146,2545,3407,1295,2153,2545,2153,1295
.dw 2546,2257,2159,1295,2553,2257,2553,1295
.dw 2258,2257,2559,1295,2265,2257,2265,1295
.dw 2850,2257,2271,1295,2857,2257,2857,1295
.dw 3826,2257,2863,1295,3833,2257,3833,1295
.dw 2258,2145,3839,1295,2265,2257,2265,1295
.dw 2850,2545,2271,1295,2857,2545,2857,1295
.dw 3826,2545,2863,1295,3833,2545,3833,1295
.dw 2850,2849,3839,1295,2857,2849,2857,1295
.dw 2546,2849,2863,1295,2553,2849,2553,1295
; Pattern 1:
.dw 2258,15,1904,1365,2258,15,15,1365
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 3826,15,1904,1349,3826,15,15,1349
.dw 2258,15,1916,1365,2258,15,15,1365
.dw 2850,15,1904,1365,2850,15,15,1365
.dw 3826,15,1916,1365,3826,15,15,1365
.dw 2258,15,1904,1349,2258,15,15,1349
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 2146,15,1904,1365,2146,15,15,1365
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 3394,15,1904,1349,3394,15,15,1349
.dw 2146,15,1916,1365,2146,15,15,1365
.dw 2850,15,1904,1365,2850,15,15,1365
.dw 3394,15,1916,1365,3394,15,15,1365
.dw 2146,15,1904,1349,2146,15,15,1349
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 1906,15,1904,1365,1906,15,15,1365
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 3826,15,1904,1349,3826,15,15,1349
.dw 1906,15,1916,1365,1906,15,15,1365
.dw 2850,15,1904,1365,2850,15,15,1365
.dw 3826,15,1916,1365,3826,15,15,1365
.dw 1906,15,1904,1349,1906,15,15,1349
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 1906,15,1904,1365,1906,15,15,1365
.dw 2546,15,1916,1365,2546,15,15,1365
.dw 3826,15,1904,1349,3826,15,15,1349
.dw 1906,15,1916,1365,1906,15,15,1365
.dw 2546,15,1904,1365,2546,15,15,1365
.dw 3826,15,1916,1365,3826,15,15,1365
.dw 1906,15,1904,1349,1906,15,15,1349
.dw 2546,15,1916,1365,2546,15,15,1365
; Pattern 2:
.dw 2258,4049,15,1295,2265,3825,2265,1295
.dw 2850,3825,2271,1295,2857,3825,2857,1295
.dw 3826,3825,2863,1295,3833,3825,3833,1295
.dw 2258,3825,3839,1295,2265,3825,2265,1295
.dw 2850,2849,2271,1295,2857,2849,2857,1295
.dw 3826,2849,2863,1295,3833,2849,3833,1295
.dw 2258,2545,3839,1295,2265,2545,2265,1295
.dw 2850,3025,2271,1295,2857,3025,2857,1295
.dw 2546,3025,2863,1295,2553,3025,2553,1295
.dw 3026,3025,2559,1295,3033,3025,3033,1295
.dw 3826,3025,3039,1295,3833,3025,3833,1295
.dw 2546,3025,3839,1295,2553,3025,2553,1295
.dw 3026,3025,2559,1295,3033,3025,3033,1295
.dw 3826,3025,3039,1295,3833,3025,3833,1295
.dw 2546,3025,3839,1295,2553,3025,2553,1295
.dw 2258,3025,2559,1295,2265,3025,2265,1295
.dw 2146,3601,2271,1295,2153,3393,2153,1295
.dw 2546,3393,2159,1295,2553,3393,2553,1295
.dw 3394,3393,2559,1295,3401,3393,3401,1295
.dw 2146,3393,3407,1295,2153,3393,2153,1295
.dw 2546,2145,2159,1295,2553,2145,2553,1295
.dw 3394,2145,2559,1295,3401,2145,3401,1295
.dw 2146,2545,3407,1295,2153,2545,2153,1295
.dw 2546,2257,2159,1295,2553,2257,2553,1295
.dw 2258,2257,2559,1295,2265,2257,2265,1295
.dw 2850,2257,2271,1295,2857,2257,2857,1295
.dw 3826,2257,2863,1295,3833,2257,3833,1295
.dw 2258,2145,3839,1295,2265,2257,2265,1295
.dw 2850,2545,2271,1295,2857,2545,2857,1295
.dw 3826,2545,2863,1365,3833,2545,3833,1365
.dw 2850,2849,1904,1365,2857,2849,15,1365
.dw 2546,2849,1916,1365,2553,2849,15,1365
; Pattern 3:
.dw 2258,15,1904,1365,2258,15,15,1365
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 3826,15,1904,1349,3826,15,15,1349
.dw 2258,15,1916,1365,2258,15,15,1365
.dw 2850,15,1904,1365,2850,15,15,1365
.dw 3826,15,1916,1365,3826,15,15,1365
.dw 2258,15,1904,1349,2258,15,15,1349
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 2146,15,1904,1365,2146,15,15,1365
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 3394,15,1904,1349,3394,15,15,1349
.dw 2146,15,1916,1365,2146,15,15,1365
.dw 2850,15,1904,1365,2850,15,15,1365
.dw 3394,15,1916,1365,3394,15,15,1365
.dw 2146,15,1904,1349,2146,15,15,1349
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 1906,15,1904,1365,1906,15,15,1365
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 3826,15,1904,1349,3826,15,15,1349
.dw 1906,15,1916,1365,1906,15,15,1365
.dw 2850,15,1904,1365,2850,15,15,1365
.dw 3826,15,1916,1365,3826,15,15,1365
.dw 1906,15,1904,1349,1906,15,15,1349
.dw 2850,15,1916,1365,2850,15,15,1365
.dw 1906,15,1904,1365,1906,15,15,1365
.dw 2546,15,1916,1365,2546,15,15,1365
.dw 3826,15,1904,1349,3826,15,15,1349
.dw 1906,15,1916,1365,1906,15,15,1365
.dw 2546,15,1904,1365,2546,15,15,1365
.dw 3826,2545,1916,1365,3826,2545,15,1365
.dw 1906,2849,1904,1344,1906,2849,15,1295
.dw 2546,2545,1916,1356,2546,2545,15,1344
; Pattern 4:
.dw 2258,2849,1904,1365,2258,2857,15,1365
.dw 2850,2860,1916,1365,2850,2862,15,1365
.dw 3826,2401,1904,1344,3826,2257,15,1295
.dw 2258,2257,1916,1365,2258,2257,15,1365
.dw 2850,2545,1904,1365,2850,2545,15,1365
.dw 3826,2257,1916,1365,3826,2257,15,1365
.dw 2258,2257,1904,1344,2258,2257,15,1295
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 2146,2849,1904,1365,2146,2849,15,1365
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 3394,2849,1904,1344,3394,2849,15,1295
.dw 2146,2849,1916,1365,2146,2849,15,1365
.dw 2850,3025,1904,1365,2850,3025,15,1365
.dw 3394,3025,1916,1365,3394,3025,15,1365
.dw 2146,2849,1904,1344,2146,2849,15,1295
.dw 2850,3393,1916,1365,2850,3393,15,1365
.dw 1906,3393,1904,1365,1906,3393,15,1365
.dw 2850,3393,1916,1365,2850,3393,15,1365
.dw 3826,2145,1904,1344,3826,2145,15,1295
.dw 1906,2145,1916,1365,1906,2145,15,1365
.dw 2850,2257,1904,1365,2850,2257,15,1365
.dw 3826,2145,1916,1365,3826,2145,15,1365
.dw 1906,2145,1904,1344,1906,2145,15,1295
.dw 2850,2545,1916,1365,2850,2545,15,1365
.dw 1906,2545,1904,1365,1906,2545,15,1365
.dw 2546,2545,1916,1365,2546,2545,15,1365
.dw 3826,2545,1904,1344,3826,2545,15,1295
.dw 1906,2545,1916,1365,1906,2545,15,1365
.dw 2546,2849,1904,1365,2546,2849,15,1365
.dw 3826,2849,1916,1365,3826,2849,15,1365
.dw 1906,2545,1904,1344,1906,2545,15,1295
.dw 2546,2545,1916,1365,2546,2545,15,1365
; Pattern 5:
.dw 2258,2849,1904,1365,2258,2857,15,1365
.dw 2850,2860,1916,1365,2850,2862,15,1365
.dw 3826,2401,1904,1344,3826,2257,15,1295
.dw 2258,2257,1916,1365,2258,2257,15,1365
.dw 2850,2545,1904,1365,2850,2545,15,1365
.dw 3826,2257,1916,1365,3826,2257,15,1365
.dw 2258,2257,1904,1344,2258,2257,15,1295
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 2146,2849,1904,1365,2146,2849,15,1365
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 3394,2849,1904,1344,3394,2849,15,1295
.dw 2146,2849,1916,1365,2146,2849,15,1365
.dw 2850,3025,1904,1365,2850,3025,15,1365
.dw 3394,3025,1916,1365,3394,3025,15,1365
.dw 2146,2849,1904,1344,2146,2849,15,1295
.dw 2850,3393,1916,1365,2850,3393,15,1365
.dw 1906,3393,1904,1365,1906,3393,15,1365
.dw 2850,3393,1916,1365,2850,3393,15,1365
.dw 3826,2145,1904,1344,3826,2145,15,1295
.dw 1906,2145,1916,1365,1906,2145,15,1365
.dw 2850,2257,1904,1365,2850,2257,15,1365
.dw 3826,2145,1916,1365,3826,2145,15,1365
.dw 1906,2145,1904,1344,1906,2145,15,1295
.dw 2850,1905,1916,1365,2850,1905,15,1365
.dw 1906,1905,1904,1365,1906,1905,15,1365
.dw 2546,1905,1916,1365,2546,1905,15,1365
.dw 3826,1905,1904,1344,3826,1906,15,1295
.dw 1906,1907,1916,1365,1906,1908,15,1365
.dw 2546,1909,1904,1365,2546,1910,15,1365
.dw 3826,1910,1916,1365,3826,1911,15,1365
.dw 1906,1912,1904,1344,1906,1913,15,1295
.dw 2546,1914,1916,1356,2546,1915,15,1344
; Pattern 6:
.dw 2258,3025,1904,1365,2265,2849,15,1365
.dw 2850,2849,1916,1365,2857,2850,15,1365
.dw 3826,2851,15,1365,3833,2852,15,1365
.dw 2258,2853,1916,1365,2265,2854,15,1366
.dw 2850,2854,15,1367,2857,2855,15,1368
.dw 3826,2856,1916,1369,3833,2857,15,1370
.dw 2258,2858,15,1371,2265,2859,15,1372
.dw 2850,2859,1916,1373,2857,2860,15,1373
.dw 2546,2861,1904,1365,2553,2862,15,1365
.dw 3026,2863,1916,1365,3033,2863,15,1365
.dw 3826,2863,15,1365,3833,2863,15,1365
.dw 2546,2863,1916,1365,2553,2863,15,1366
.dw 3026,2863,15,1367,3033,2863,15,1368
.dw 3826,2863,1916,1369,3833,2863,15,1370
.dw 2546,2863,15,1371,2553,2863,15,1372
.dw 2258,2863,1916,1373,2265,2863,15,1373
.dw 2146,2863,1904,1365,2153,2863,15,1365
.dw 2546,2863,1916,1365,2553,2863,15,1365
.dw 3394,2863,15,1365,3401,2863,15,1365
.dw 2146,2863,1916,1365,2153,2863,15,1366
.dw 2546,2863,15,1367,2553,2863,15,1368
.dw 3394,2863,1916,1369,3401,2863,15,1370
.dw 2146,2863,15,1371,2153,2863,15,1372
.dw 2546,2863,1916,1373,2553,2863,15,1373
.dw 2258,2863,1904,1365,2265,2863,15,1365
.dw 2850,2863,1916,1365,2857,2863,15,1365
.dw 3826,2863,15,1365,3833,2863,15,1365
.dw 2258,2863,1916,1365,2265,2863,15,1366
.dw 2850,2863,15,1367,2857,2863,15,1368
.dw 3826,2863,1916,1369,3833,2863,15,1370
.dw 2850,2863,15,1371,2857,2863,15,1372
.dw 2546,2863,1916,1373,2553,2863,15,1373
; Pattern 7:
.dw 2258,15,1904,1365,2265,15,15,1365
.dw 2850,15,1916,1365,2857,15,15,1365
.dw 3826,15,15,1365,3833,15,15,1365
.dw 2258,15,1916,1365,2265,15,15,1366
.dw 2850,15,15,1367,2857,15,15,1368
.dw 3826,15,1916,1369,3833,15,15,1370
.dw 2258,15,15,1371,2265,15,15,1372
.dw 2850,15,1916,1373,2857,15,15,1373
.dw 2546,15,1904,1365,2553,15,15,1365
.dw 3026,15,1916,1365,3033,15,15,1365
.dw 3826,15,15,1365,3833,15,15,1365
.dw 2546,15,1916,1365,2553,15,15,1366
.dw 3026,15,15,1367,3033,15,15,1368
.dw 3826,15,1916,1369,3833,15,15,1370
.dw 2546,15,15,1371,2553,15,15,1372
.dw 2258,15,1916,1373,2265,15,15,1373
.dw 2146,15,1904,1365,2153,15,15,1365
.dw 2546,15,1916,1365,2553,15,15,1365
.dw 3394,15,15,1365,3401,15,15,1365
.dw 2146,15,1916,1365,2153,15,15,1366
.dw 2546,15,15,1367,2553,15,15,1368
.dw 3394,15,1916,1369,3401,15,15,1370
.dw 2146,15,15,1371,2153,15,15,1372
.dw 2546,15,1916,1373,2553,15,15,1373
.dw 2258,15,1904,1365,2265,15,15,1365
.dw 2850,15,1916,1365,2857,15,15,1365
.dw 3826,15,15,1365,3833,15,15,1365
.dw 2258,15,1916,1365,2265,15,15,1366
.dw 2850,15,15,1367,2856,15,15,1368
.dw 3826,15,1916,1365,3830,15,15,1366
.dw 2850,15,1904,1349,2853,15,15,1350
.dw 2546,15,1916,1349,2546,15,15,1350
; Pattern 8:
.dw 2258,3025,1904,1365,2258,3025,15,1365
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 3826,2849,1904,1344,3826,2849,15,1295
.dw 2258,2257,1916,1365,2258,2257,15,1365
.dw 2850,2257,1904,1365,2850,2257,15,1365
.dw 3826,2257,1916,1365,3826,2257,15,1365
.dw 2258,2257,1904,1344,2258,2257,15,1295
.dw 2850,2257,1916,1365,2850,2257,15,1365
.dw 2146,3025,1904,1365,2146,3025,15,1365
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 3394,2849,1904,1344,3394,2849,15,1295
.dw 2146,1905,1916,1365,2146,1905,15,1365
.dw 2850,1905,1904,1365,2850,1905,15,1365
.dw 3394,1905,1916,1365,3394,1905,15,1365
.dw 2146,1905,1904,1344,2146,1905,15,1295
.dw 2850,1905,1916,1365,2850,1905,15,1365
.dw 1906,3025,1904,1365,1906,3025,15,1365
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 3826,2849,1904,1344,3826,2849,15,1295
.dw 1906,3393,1916,1365,1906,3393,15,1365
.dw 2850,3393,1904,1365,2850,3393,15,1365
.dw 3826,3393,1916,1365,3826,3393,15,1365
.dw 1906,3393,1904,1344,1906,3393,15,1295
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 1906,3025,1904,1365,1906,3025,15,1365
.dw 2546,2849,1916,1365,2546,2849,15,1365
.dw 3826,2849,1904,1344,3826,2849,15,1295
.dw 1906,2257,1916,1365,1906,2257,15,1365
.dw 2546,2257,1904,1365,2546,2257,15,1365
.dw 3826,2257,1916,1365,3826,2257,15,1365
.dw 1906,2545,1904,1344,1906,2545,15,1295
.dw 2546,2545,1916,1365,2546,2545,15,1365
; Pattern 9:
.dw 2258,3025,1904,1365,2258,3025,15,1365
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 3826,2849,1904,1344,3826,2849,15,1295
.dw 2258,2257,1916,1365,2258,2257,15,1365
.dw 2850,2257,1904,1365,2850,2257,15,1365
.dw 3826,2257,1916,1365,3826,2257,15,1365
.dw 2258,2257,1904,1344,2258,2257,15,1295
.dw 2850,2257,1916,1365,2850,2257,15,1365
.dw 2146,3025,1904,1365,2146,3025,15,1365
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 3394,2849,1904,1344,3394,2849,15,1295
.dw 2146,1905,1916,1365,2146,1905,15,1365
.dw 2850,1905,1904,1365,2850,1905,15,1365
.dw 3394,1905,1916,1365,3394,1905,15,1365
.dw 2146,1905,1904,1344,2146,1905,15,1295
.dw 2850,1905,1916,1365,2850,1905,15,1365
.dw 1906,3025,1904,1365,1906,3025,15,1365
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 3826,2849,1904,1344,3826,2849,15,1295
.dw 1906,3393,1916,1365,1906,3393,15,1365
.dw 2850,3393,1904,1365,2850,3393,15,1365
.dw 3826,3393,1916,1365,3826,3393,15,1365
.dw 1906,3393,1904,1344,1906,3393,15,1295
.dw 2850,2849,1916,1365,2850,2849,15,1365
.dw 1906,3025,1904,1365,1906,3025,15,1365
.dw 2546,2849,1916,1365,2546,2849,15,1365
.dw 3826,2849,1904,1344,3826,2849,15,1295
.dw 1906,2257,1916,1365,1906,2257,15,1365
.dw 2546,2257,1904,1365,2546,2257,15,1365
.dw 3826,2257,1916,1365,3826,2257,15,1365
.dw 1906,2545,1904,1344,1906,2545,15,1295
.dw 2546,2545,1916,1356,2546,2545,15,1344

black_palette:

.db 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0
.db 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0

palette:
.db $00 $01 $0B $2A $2B $2A $3F $17 $15 $35 $34 $03 $02 $30 $20 $00
.db $00 $30 $3A $3A $3F $3F $3F $3E $3E $3A $3D $39 $38 $34 $34 $34

Tiles:
; Tile number 0x000
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00


;Sega's Logo Letter S

; Tile number 0x001
.db $3F,$30,$20,$0F,$7F,$7E,$3E,$7E,$DF,$F0,$A0,$7F,$37,$7F,$4F,$FF,$67,$3F,$5F,$DF,$A7,$FE,$58,$59,$63,$7F,$1F,$DF,$1F,$1F,$70,$E1
; Tile number 0x002
.db $00,$C0,$20,$00,$E0,$00,$00,$20,$A0,$60,$20,$80,$E0,$80,$80,$A0,$E0,$80,$80,$A0,$00,$00,$00,$00,$80,$00,$00,$00,$C0,$C0,$C0,$C0
; Tile number 0x003
.db $03,$5D,$3E,$7F,$44,$4B,$5F,$3F,$0D,$0F,$87,$73,$00,$0F,$7F,$FF,$87,$87,$80,$78,$00,$43,$3F,$FF,$01,$43,$3E,$FF,$00,$00,$00,$00
; Tile number 0x004
.db $E0,$C0,$40,$E0,$E0,$80,$00,$20,$C0,$60,$40,$C0,$C0,$E0,$40,$40,$E0,$E0,$40,$C0,$C0,$80,$C0,$C0,$80,$80,$00,$80,$00,$00,$00,$00

;Sega's Logo Letter E

; Tile number 0x005
.db $38,$27,$00,$18,$5F,$3E,$7E,$7E,$BF,$F6,$40,$F9,$3F,$FF,$CF,$FF,$7F,$6F,$9F,$DF,$2F,$78,$D0,$DF,$2F,$7F,$DF,$DF,$1E,$5D,$C0,$E2
; Tile number 0x006
.db $80,$40,$20,$80,$C0,$20,$00,$00,$20,$E0,$20,$00,$C0,$20,$00,$00,$E0,$80,$80,$A0,$80,$00,$40,$80,$C0,$80,$80,$C0,$C0,$40,$40,$80
; Tile number 0x007
.db $31,$3F,$CF,$DF,$01,$1F,$DF,$FF,$0F,$1F,$D0,$F8,$20,$2F,$DF,$DF,$0F,$3F,$C0,$F0,$00,$47,$3F,$7F,$00,$27,$1F,$3F,$00,$00,$00,$00
; Tile number 0x008
.db $C0,$80,$80,$C0,$C0,$80,$80,$C0,$A0,$60,$20,$80,$E0,$40,$40,$60,$40,$80,$20,$40,$60,$C0,$C0,$E0,$40,$E0,$C0,$C0,$00,$00,$00,$00

;Sega's Logo Letter G

; Tile number 0x009
.db $1F,$20,$00,$1F,$7F,$3F,$7F,$7F,$F9,$DF,$60,$F8,$3F,$FF,$CF,$DF,$0F,$FF,$DF,$DF,$2F,$78,$D0,$D7,$2F,$7C,$D4,$D4,$2F,$3C,$D0,$D3
; Tile number 0x00A
.db $00,$C0,$20,$00,$C0,$20,$00,$00,$80,$40,$20,$80,$C0,$A0,$80,$80,$C0,$A0,$80,$80,$C0,$00,$20,$C0,$C0,$A0,$80,$80,$E0,$C0,$40,$E0
; Tile number 0x00B
.db $29,$3F,$D7,$D7,$01,$17,$D7,$FF,$0D,$1F,$D3,$FB,$00,$0F,$DF,$FF,$06,$B7,$40,$D8,$00,$47,$3F,$FF,$00,$2F,$1F,$7F,$00,$00,$00,$00
; Tile number 0x00C
.db $C0,$60,$40,$C0,$C0,$60,$40,$C0,$40,$E0,$40,$40,$E0,$40,$40,$E0,$60,$E0,$40,$60,$60,$E0,$E0,$E0,$60,$E0,$E0,$E0,$00,$00,$00,$00

;Sega's Logo Letter A
; Tile number 0x00D
.db $07,$05,$05,$02,$0F,$0E,$06,$0E,$1F,$1E,$0E,$0E,$17,$1F,$1F,$1D,$37,$3C,$38,$19,$27,$3A,$1A,$1F,$07,$3E,$3A,$3B,$43,$77,$77,$3F
; Tile number 0x00E
.db $00,$00,$00,$00,$80,$00,$80,$80,$80,$40,$00,$00,$C0,$40,$40,$40,$C0,$00,$20,$00,$E0,$80,$80,$A0,$E0,$C0,$C0,$C0,$F0,$50,$50,$C0
; Tile number 0x00F
.db $41,$5F,$37,$37,$0A,$1F,$75,$75,$82,$9F,$ED,$7D,$03,$8C,$6F,$FF,$17,$17,$E8,$E8,$0C,$8F,$53,$F3,$04,$97,$43,$FB,$00,$00,$00,$00
; Tile number 0x000
.db $70,$A0,$20,$30,$F0,$70,$70,$F0,$F8,$A8,$A8,$E0,$B8,$F0,$B0,$B8,$F8,$F0,$70,$30,$18,$F0,$F0,$F0,$F8,$60,$E0,$E0,$00,$00,$00,$00


; Tile number 0x011
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00
; Tile number 0x012
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$C7,$C7,$00,$00,$C6,$C6,$00,$00,$C6,$C6,$00
; Tile number 0x013
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$80,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
; Tile number 0x014
.db $00,$FF,$FF,$00,$00,$FE,$FF,$00,$01,$FF,$FE,$01,$01,$FD,$FE,$01,$03,$FF,$FC,$03,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
; Tile number 0x015
.db $F8,$FB,$07,$F8,$F8,$FF,$0F,$F0,$F0,$FF,$0F,$F0,$E0,$EF,$1F,$E0,$E0,$FF,$1F,$E0,$C0,$51,$31,$40,$20,$10,$31,$00,$01,$31,$30,$01
; Tile number 0x016
.db $07,$FF,$F8,$07,$1F,$EF,$F0,$0F,$3F,$DF,$E0,$1F,$7E,$BF,$C1,$3E,$7C,$FF,$87,$78,$F8,$FF,$07,$F8,$F0,$F7,$0F,$F0,$F0,$FF,$1F,$E0
; Tile number 0x017
.db $FF,$FF,$00,$FF,$FC,$FC,$17,$E8,$00,$7F,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$F1,$F1,$00,$11,$D1,$E0,$11,$71,$F1,$80,$71
; Tile number 0x018
.db $FF,$FF,$00,$FF,$7F,$7F,$C0,$3F,$0F,$EF,$F0,$0F,$03,$FB,$FC,$03,$01,$FF,$FF,$00,$00,$FE,$FE,$00,$00,$7E,$FE,$00,$E0,$FE,$3E,$C0
; Tile number 0x019
.db $80,$FF,$FF,$00,$C0,$DF,$3F,$C0,$F0,$FF,$1F,$E0,$F8,$FF,$0F,$F0,$FC,$FF,$07,$F8,$30,$30,$00,$30,$30,$30,$00,$30,$30,$30,$00,$30
; Tile number 0x01A
.db $3F,$FF,$C1,$3E,$1F,$DF,$E0,$1F,$0F,$EF,$F0,$0F,$0F,$FF,$F0,$0F,$07,$F7,$F8,$07,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
; Tile number 0x01B
.db $00,$FF,$FF,$00,$80,$7F,$FF,$00,$80,$FF,$7F,$80,$80,$BF,$7F,$80,$C0,$FF,$3F,$C0,$40,$43,$03,$40,$40,$43,$03,$40,$40,$42,$02,$40
; Tile number 0x01C
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$80,$80,$00,$00,$00,$00,$00,$00,$00,$00,$00
; Tile number 0x01D
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$70,$70,$00,$00,$30,$30,$00,$20,$30,$30,$20
; Tile number 0x01E
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$80,$FF,$FF,$80,$00,$3F,$3F,$00,$00,$1F,$1F,$00
; Tile number 0x01F
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$80,$80,$00,$00,$80,$80,$00,$00,$80,$80,$00
; Tile number 0x020
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$04,$07,$07,$04,$00,$01,$01,$00,$00,$01,$01,$00
; Tile number 0x021
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$E0,$E0,$00,$00,$C0,$C0,$00,$00,$80,$80,$00
; Tile number 0x022
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$80,$80,$00,$00,$80,$80,$00,$40,$C0,$C0,$40
; Tile number 0x023
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$03,$03,$00,$00,$03,$03,$00,$00,$03,$03,$00
; Tile number 0x024
.db $00,$E3,$E3,$00,$00,$E3,$E3,$00,$00,$E3,$E3,$00,$00,$E3,$E3,$00,$00,$E3,$E3,$00,$00,$E3,$E3,$00,$00,$E3,$E3,$00,$00,$E3,$E3,$00
; Tile number 0x025
.db $00,$8C,$8C,$00,$00,$8C,$8C,$00,$00,$8C,$8C,$00,$00,$8C,$8C,$00,$00,$8C,$8C,$00,$00,$8C,$8C,$00,$00,$8C,$8C,$00,$00,$8C,$8C,$00
; Tile number 0x026
.db $05,$7A,$7B,$07,$05,$7A,$7F,$03,$01,$7E,$7F,$03,$02,$7D,$7D,$03,$02,$7F,$7D,$01,$02,$7D,$7F,$01,$00,$7F,$7F,$01,$01,$7E,$7E,$01
; Tile number 0x027
.db $FC,$02,$FE,$F8,$FE,$00,$FC,$FE,$FE,$00,$FE,$FE,$FE,$00,$FE,$FE,$FE,$00,$FE,$FE,$FE,$00,$FE,$FE,$7E,$80,$FE,$FE,$7E,$80,$FE,$FE
; Tile number 0x028
.db $00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$3E,$01,$3B,$3C,$3F,$00,$3D,$3E
; Tile number 0x029
.db $00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$3E,$3E,$00,$00,$3E,$3E,$00,$00,$3E,$3E,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00
; Tile number 0x02A
.db $00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00,$00,$3F,$3F,$00
; Tile number 0x02B
.db $00,$C6,$C6,$00,$00,$C6,$C6,$00,$00,$C6,$C6,$00,$00,$C6,$C6,$00,$00,$C6,$C6,$00,$00,$C6,$C6,$00,$00,$C6,$C6,$00,$00,$C6,$C6,$00
; Tile number 0x02C
.db $06,$FE,$F8,$06,$0E,$F6,$F8,$06,$06,$F6,$F8,$06,$0E,$FE,$F8,$06,$0E,$FE,$F0,$0E,$0E,$FE,$F0,$0E,$0E,$FE,$F0,$0E,$0E,$FE,$F0,$0E
; Tile number 0x02D
.db $01,$31,$30,$01,$01,$31,$30,$01,$01,$31,$30,$01,$01,$31,$30,$01,$01,$31,$30,$01,$01,$31,$30,$01,$01,$31,$30,$01,$01,$31,$30,$01
; Tile number 0x02E
.db $F1,$EE,$1F,$E0,$E1,$FF,$1E,$E1,$C3,$DF,$3E,$C1,$E3,$DF,$3C,$C3,$C7,$FB,$3C,$C3,$C3,$FB,$7C,$83,$C3,$FB,$7C,$83,$C3,$FF,$7C,$83
; Tile number 0x02F
.db $F1,$F1,$00,$F1,$F1,$F1,$00,$F1,$E1,$F0,$31,$C0,$C0,$F1,$31,$C0,$C0,$F1,$31,$C0,$C0,$F1,$71,$80,$C0,$F1,$31,$C0,$C0,$D1,$31,$C0
; Tile number 0x030
.db $F8,$F6,$0E,$F0,$F8,$FA,$06,$F8,$FC,$FC,$82,$7C,$3E,$BE,$C0,$3E,$1E,$DE,$E0,$1E,$0E,$EE,$F0,$0E,$0E,$FE,$F8,$06,$06,$F6,$F8,$06
; Tile number 0x031
.db $1F,$3F,$20,$1F,$0F,$2F,$30,$0F,$0F,$3F,$30,$0F,$0F,$3F,$38,$07,$0F,$37,$38,$07,$07,$3F,$38,$07,$07,$3F,$3C,$03,$07,$3F,$3C,$03
; Tile number 0x032
.db $03,$8F,$8C,$03,$83,$0F,$8E,$01,$81,$8D,$8E,$01,$81,$8D,$0E,$81,$83,$8D,$0E,$81,$81,$8F,$0F,$80,$80,$8F,$0F,$80,$80,$8F,$0F,$80
; Tile number 0x033
.db $C0,$C2,$02,$C0,$C0,$C2,$02,$C0,$C0,$C2,$02,$C0,$C0,$C2,$02,$C0,$C0,$C2,$02,$C0,$C0,$C2,$02,$C0,$C0,$C2,$82,$40,$00,$C2,$C2,$00
; Tile number 0x034
.db $00,$1F,$1F,$00,$00,$1F,$1F,$00,$00,$1F,$1F,$00,$00,$1F,$1F,$00,$00,$1F,$1F,$00,$00,$1F,$1F,$00,$00,$1F,$1F,$00,$00,$1F,$1F,$00
; Tile number 0x035
.db $00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00
; Tile number 0x036
.db $00,$11,$11,$00,$00,$11,$11,$00,$00,$11,$11,$00,$00,$11,$11,$00,$00,$11,$11,$00,$00,$11,$11,$00,$00,$11,$11,$00,$00,$11,$11,$00
; Tile number 0x037
.db $00,$8F,$8F,$00,$00,$8F,$8F,$00,$00,$8F,$8F,$00,$00,$8F,$8F,$00,$00,$8F,$8F,$00,$00,$8F,$8F,$00,$00,$8F,$8F,$00,$00,$8F,$8F,$00
; Tile number 0x038
.db $00,$87,$87,$00,$00,$87,$87,$00,$00,$87,$87,$00,$00,$80,$80,$00,$00,$80,$80,$00,$00,$87,$87,$00,$00,$87,$87,$00,$00,$87,$87,$00
; Tile number 0x039
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$07,$07,$00,$00,$07,$07,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x03A
.db $00,$E3,$E3,$00,$00,$E0,$E0,$00,$00,$E0,$E0,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$03,$FC,$FE,$01,$01,$FE,$FE,$01
; Tile number 0x03B
.db $00,$FF,$FF,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$E0,$1F,$3F,$C0,$FE,$01,$F3,$FC
; Tile number 0x03C
.db $00,$8C,$8C,$00,$00,$0C,$0C,$00,$00,$1E,$1E,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x03D
.db $01,$7E,$7E,$01,$00,$00,$00,$00,$00,$00,$00,$00,$01,$FE,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x03E
.db $7E,$80,$FE,$FE,$06,$00,$06,$06,$07,$00,$07,$07,$3F,$C0,$FF,$FF,$BF,$40,$7F,$FF,$BF,$40,$7F,$FF,$BF,$40,$7F,$FF,$BF,$40,$7F,$FF
; Tile number 0x03F
.db $3F,$00,$3F,$3F,$00,$00,$00,$00,$00,$00,$00,$00,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF
; Tile number 0x040
.db $80,$7E,$FE,$00,$00,$06,$06,$00,$00,$06,$06,$00,$F0,$0F,$FF,$E0,$F8,$07,$EF,$F0,$F8,$07,$F7,$F8,$FC,$03,$FB,$FC,$FE,$01,$FF,$FC
; Tile number 0x041
.db $00,$3F,$3F,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x042
.db $00,$C6,$C6,$00,$00,$06,$06,$00,$10,$0F,$0F,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x043
.db $00,$3F,$3F,$00,$00,$00,$00,$00,$80,$00,$00,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x044
.db $0E,$FE,$F0,$0E,$00,$00,$00,$00,$00,$00,$00,$00,$0F,$FF,$F8,$07,$07,$F7,$F8,$07,$07,$FF,$F8,$07,$07,$FF,$F8,$07,$03,$FB,$FC,$03
; Tile number 0x045
.db $01,$31,$30,$01,$00,$30,$30,$00,$80,$38,$78,$00,$83,$BF,$7C,$83,$C1,$FD,$3E,$C1,$C1,$FF,$3E,$C1,$C0,$DE,$3F,$C0,$E0,$FF,$1F,$E0
; Tile number 0x046
.db $C3,$FF,$7C,$83,$00,$00,$00,$00,$00,$00,$00,$00,$F0,$EF,$1F,$E0,$F0,$FF,$0F,$F0,$F0,$F7,$0F,$F0,$FC,$FB,$07,$F8,$FC,$FD,$83,$7C
; Tile number 0x047
.db $F0,$F1,$01,$F0,$30,$30,$00,$30,$38,$38,$00,$38,$7F,$7F,$80,$7F,$00,$F1,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x048
.db $06,$FE,$F8,$06,$00,$00,$00,$00,$00,$00,$00,$00,$8F,$77,$F8,$07,$0F,$FF,$F0,$0F,$1F,$FF,$E0,$1F,$3E,$BE,$C1,$3E,$FE,$FF,$01,$FE
; Tile number 0x049
.db $03,$3B,$3C,$03,$03,$3F,$3C,$03,$03,$7F,$7C,$03,$07,$7B,$FC,$03,$03,$7B,$FC,$03,$07,$FF,$F8,$07,$07,$FF,$F8,$07,$07,$F7,$F8,$07
; Tile number 0x04A
.db $80,$8F,$0F,$80,$80,$8F,$0F,$80,$80,$8F,$0F,$80,$C0,$FF,$7F,$80,$C0,$FF,$7F,$80,$C0,$FF,$7F,$80,$80,$BF,$7F,$80,$C0,$BF,$7F,$80
; Tile number 0x04B
.db $00,$C2,$C2,$00,$00,$C3,$C3,$00,$00,$C3,$C3,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x04C
.db $00,$1F,$1F,$00,$00,$00,$00,$00,$00,$80,$80,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x04D
.db $00,$FE,$FE,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x04E
.db $00,$11,$11,$00,$00,$31,$31,$00,$00,$71,$71,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x04F
.db $00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FE,$FE,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x050
.db $00,$1F,$1F,$00,$00,$11,$11,$00,$00,$11,$11,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x051
.db $00,$8F,$8F,$00,$00,$8F,$8F,$00,$00,$8F,$8F,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x052
.db $00,$87,$87,$00,$00,$C0,$C0,$00,$00,$E0,$E0,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x053
.db $00,$FF,$FF,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x054
.db $01,$FF,$FE,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x055
.db $7E,$81,$FE,$FF,$3F,$C0,$FF,$FF,$9F,$60,$FF,$7F,$4F,$B0,$BF,$7F,$47,$B8,$FF,$3F,$27,$D8,$DF,$3F,$23,$DC,$FF,$1F,$11,$FE,$EF,$0F
; Tile number 0x056
.db $E0,$1F,$7F,$80,$FC,$03,$EF,$F0,$FF,$00,$FD,$FE,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF
; Tile number 0x057
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$E0,$1F,$7F,$80,$F9,$06,$EF,$F0,$FF,$00,$FC,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF
; Tile number 0x058
.db $BF,$40,$7F,$FF,$BF,$40,$7F,$FF,$BF,$40,$7F,$FF,$BF,$40,$7F,$FF,$7F,$80,$FF,$FF,$FF,$00,$FF,$FF,$BF,$40,$FF,$FF,$DF,$20,$DF,$FF
; Tile number 0x059
.db $FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FE,$01,$FE,$FF
; Tile number 0x05A
.db $FF,$00,$FF,$FE,$FF,$00,$FE,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$F3,$0C,$F3,$FF,$80,$7F,$80,$FF,$00,$FF,$00,$FF
; Tile number 0x05B
.db $00,$FF,$FF,$00,$80,$7F,$FF,$00,$80,$7F,$7F,$80,$C0,$3F,$FF,$80,$C0,$3F,$BF,$C0,$E0,$1F,$DF,$E0,$30,$CF,$3F,$E0,$10,$EF,$0F,$F0
; Tile number 0x05C
.db $03,$FF,$FC,$03,$01,$FD,$FE,$01,$01,$FF,$FE,$01,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x05D
.db $E0,$EF,$1F,$E0,$F0,$FF,$0F,$F0,$F8,$FF,$0F,$F0,$F8,$FB,$07,$F8,$7C,$7D,$83,$7C,$7F,$FF,$C1,$3E,$3F,$FF,$E0,$1F,$1F,$FF,$F0,$0F
; Tile number 0x05E
.db $7F,$FF,$C0,$3F,$3F,$FF,$E0,$1F,$0F,$EF,$F0,$0F,$03,$FB,$FC,$03,$01,$FE,$FF,$00,$00,$FF,$FF,$00,$80,$BF,$7F,$80,$F0,$F7,$1F,$E0
; Tile number 0x05F
.db $4B,$33,$FC,$03,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$7D,$7C,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x060
.db $FC,$FD,$03,$FC,$F8,$FB,$07,$F8,$F0,$FF,$1F,$E0,$80,$BF,$7F,$80,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$01,$FF,$FE,$01,$03,$FB,$FC,$03
; Tile number 0x061
.db $0F,$FF,$F0,$0F,$0F,$EF,$F0,$0F,$1F,$FF,$E0,$1F,$3E,$FE,$C1,$3E,$3E,$BF,$C1,$3E,$FC,$FD,$83,$7C,$FC,$FF,$07,$F8,$F8,$FF,$0F,$F0
; Tile number 0x062
.db $80,$FF,$7F,$80,$00,$7F,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x063
.db $00,$FF,$FF,$0F,$08,$FF,$F7,$07,$00,$FB,$FB,$07,$04,$FB,$FF,$03,$02,$FD,$FD,$03,$02,$FD,$FF,$01,$01,$FE,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x064
.db $FF,$00,$FF,$FF,$7F,$80,$FF,$FF,$7F,$80,$FF,$FF,$3F,$C0,$FF,$FF,$1F,$E0,$FF,$FF,$0F,$F0,$FF,$FF,$0F,$F0,$FF,$FF,$87,$78,$7F,$FF
; Tile number 0x065
.db $FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FE,$01,$FF,$FF,$FE,$01,$FF,$FF,$FF,$00,$FF,$FF,$FD,$02,$FF,$FF,$FD,$02,$FF,$FF
; Tile number 0x066
.db $43,$A4,$E7,$FF,$DB,$1A,$C7,$FF,$C1,$1C,$C2,$E3,$A1,$7F,$E1,$C0,$80,$3F,$80,$C0,$80,$3F,$80,$C0,$C3,$4F,$F2,$80,$07,$84,$FC,$83
; Tile number 0x067
.db $FC,$03,$FC,$FF,$F0,$0F,$F0,$FF,$F0,$0F,$F0,$FF,$60,$9F,$E0,$FF,$60,$1F,$60,$FF,$80,$FF,$C0,$7F,$40,$3F,$00,$FF,$80,$7F,$80,$FF
; Tile number 0x068
.db $00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF
; Tile number 0x069
.db $08,$F7,$0F,$F0,$0F,$F2,$01,$FC,$00,$FF,$07,$FF,$04,$FB,$07,$FF,$02,$FD,$03,$FF,$03,$FC,$03,$FF,$01,$FE,$01,$FF,$01,$FE,$01,$FF
; Tile number 0x06A
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$38,$D7,$CF,$E0,$1E,$E1,$F9,$FE,$F9,$06,$F9,$FE,$FA,$05,$F9,$FE,$FA,$07,$F9,$FC,$F4,$0B,$F3,$FC
; Tile number 0x06B
.db $00,$F8,$F8,$07,$07,$FF,$FF,$07,$07,$FE,$FF,$06,$07,$FF,$FE,$06,$07,$FF,$FF,$07,$07,$FE,$FF,$06,$07,$FE,$FF,$06,$07,$FE,$FF,$06
; Tile number 0x06C
.db $27,$17,$38,$C7,$F7,$EB,$FE,$E1,$60,$E8,$E9,$76,$E7,$6F,$EF,$77,$E7,$FF,$FE,$E6,$06,$FF,$FF,$06,$06,$FF,$FF,$06,$06,$FF,$FF,$06
; Tile number 0x06D
.db $FF,$FF,$01,$FE,$FF,$FF,$00,$FF,$ED,$E1,$92,$F3,$FF,$BF,$FF,$BF,$3F,$F7,$FB,$33,$3F,$FF,$FF,$3F,$39,$F5,$FC,$32,$1E,$FE,$FE,$1F
; Tile number 0x06E
.db $E0,$1F,$FF,$00,$FF,$FF,$00,$FF,$DB,$CB,$2C,$EF,$BF,$B7,$76,$F7,$7B,$33,$B4,$B7,$9E,$DF,$5F,$3E,$56,$CF,$9F,$26,$7C,$BD,$FD,$3E
; Tile number 0x06F
.db $5F,$9F,$E0,$1F,$FF,$FF,$00,$FF,$F7,$D7,$18,$DF,$7E,$7F,$FF,$FC,$F4,$F5,$E5,$CE,$FE,$FF,$FF,$FE,$C6,$D5,$D3,$E8,$7C,$FF,$FF,$7C
; Tile number 0x070
.db $E0,$EF,$1F,$E0,$C0,$DF,$3F,$C0,$00,$26,$26,$D9,$FD,$FF,$FF,$FD,$DC,$EF,$FF,$CC,$DC,$EF,$FF,$CC,$DC,$EF,$FF,$CC,$DC,$EF,$FF,$CC
; Tile number 0x071
.db $40,$BF,$FF,$00,$C0,$FF,$FF,$C0,$C4,$D8,$DC,$E3,$E4,$F4,$F4,$EF,$CE,$FE,$FE,$CF,$C3,$FB,$FB,$C7,$E2,$D1,$F3,$CC,$EF,$F7,$FF,$E7
; Tile number 0x072
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$80,$FF,$7F,$00,$C0,$FF,$FF,$C0,$80,$7F,$FF,$00,$C0,$FF,$FF,$C0,$C0,$FF,$FF,$C0,$80,$BF,$BF,$C0
; Tile number 0x073
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$01,$FE,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x074
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$FF,$00,$07,$F8,$BF,$40,$7F,$FF,$4F,$B0,$BF,$7F,$27,$D8,$DF,$3F,$11,$EE,$EF,$1F
; Tile number 0x075
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$FC,$03,$9F,$E0,$FF,$00,$FC,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF
; Tile number 0x076
.db $87,$78,$FF,$7F,$43,$BC,$BF,$7F,$43,$BC,$FF,$3F,$23,$DC,$DF,$3F,$27,$D8,$FF,$1F,$EF,$10,$1F,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF
; Tile number 0x077
.db $FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF
; Tile number 0x078
.db $8F,$08,$77,$87,$1F,$00,$6F,$9F,$BF,$80,$5F,$3F,$7F,$00,$3F,$FF,$FF,$00,$7F,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF
; Tile number 0x079
.db $C0,$3F,$C0,$FF,$C0,$3F,$C0,$FF,$80,$7F,$80,$FF,$80,$7F,$80,$FF,$C0,$3F,$C0,$FF,$C0,$3F,$C0,$FF,$C0,$3F,$C0,$FF,$80,$7F,$80,$FF
; Tile number 0x07A
.db $01,$FE,$01,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF
; Tile number 0x07B
.db $F4,$0B,$F7,$F8,$E8,$17,$EF,$F0,$F0,$0F,$FF,$E0,$E0,$1F,$DF,$E0,$40,$BF,$3F,$C0,$20,$DF,$3F,$C0,$30,$CF,$1F,$E0,$10,$EF,$0F,$F0
; Tile number 0x07C
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$08,$F7,$FF,$00,$1C,$E3,$FF,$00,$04,$FB,$FF,$00
; Tile number 0x07D
.db $08,$F7,$F7,$0F,$04,$FB,$FB,$07,$02,$FD,$FD,$03,$01,$FE,$FE,$01,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x07E
.db $FF,$00,$FF,$FF,$3F,$C0,$FF,$FF,$1F,$E0,$FF,$FF,$0F,$F0,$FF,$FF,$83,$7C,$7F,$FF,$41,$BE,$BF,$7F,$30,$CF,$DF,$3F,$18,$E7,$F7,$0F
; Tile number 0x07F
.db $FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$7F,$80,$FF,$FF,$1F,$E0,$FF,$FF
; Tile number 0x080
.db $FF,$00,$FF,$FF,$FC,$03,$FC,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$E0,$FF,$F9,$06,$9F,$E0,$E0,$5F,$BF,$80,$C0,$3F,$7F,$80
; Tile number 0x081
.db $E0,$1F,$E0,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$C0,$3F,$C0,$FF,$F0,$0F,$30,$FF,$F8,$07,$98,$7F,$3C,$C3,$EC,$1F,$1E,$E1,$F6,$0F
; Tile number 0x082
.db $00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$00,$FF,$40,$BF,$40,$FF
; Tile number 0x083
.db $01,$FE,$01,$FF,$03,$FC,$02,$FF,$03,$FC,$02,$FF,$07,$F9,$04,$FE,$07,$F8,$05,$FE,$0E,$F1,$0F,$FC,$0E,$F1,$0B,$FC,$1C,$E3,$17,$F8
; Tile number 0x084
.db $A8,$57,$EF,$F0,$B0,$4F,$6F,$F0,$F0,$0F,$AF,$70,$F0,$0F,$9F,$60,$7E,$E1,$9F,$00,$74,$AB,$DF,$00,$50,$AF,$FF,$00,$20,$BF,$9F,$40
; Tile number 0x085
.db $00,$FF,$FF,$00,$0F,$F0,$FF,$00,$02,$FD,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$01,$FE,$FF,$00
; Tile number 0x086
.db $C4,$3B,$FF,$00,$8F,$70,$FF,$00,$1F,$E0,$FF,$00,$1F,$E0,$FF,$00,$3C,$C3,$FF,$00,$60,$9F,$FF,$00,$80,$7F,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x087
.db $04,$FB,$FB,$07,$03,$FC,$FE,$01,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x088
.db $07,$F8,$FF,$FF,$00,$FF,$FF,$FF,$80,$7F,$7F,$FF,$60,$9F,$DF,$3F,$10,$EF,$EF,$1F,$0C,$F3,$FB,$07,$02,$FD,$FF,$01,$01,$FE,$FF,$00
; Tile number 0x089
.db $BF,$40,$FF,$FF,$1F,$E0,$FF,$FF,$1F,$E0,$FF,$FF,$1F,$E0,$FF,$FF,$0F,$F0,$FF,$FF,$0F,$F0,$FF,$FF,$07,$F8,$FF,$FF,$83,$7C,$7F,$FF
; Tile number 0x08A
.db $80,$7F,$7F,$80,$80,$7F,$FF,$00,$80,$7F,$FF,$00,$80,$7F,$FF,$00,$80,$7F,$7F,$80,$80,$7F,$7F,$80,$C0,$3F,$FF,$80,$A0,$1F,$3F,$C0
; Tile number 0x08B
.db $0F,$F8,$F3,$07,$13,$E0,$F1,$0F,$27,$C6,$E4,$15,$3F,$FF,$DC,$1C,$03,$C2,$C1,$2C,$02,$C3,$C1,$2C,$06,$C7,$C5,$24,$06,$C5,$C7,$24
; Tile number 0x08C
.db $7F,$80,$7F,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$7F,$FF,$BF,$C0,$7F,$7F,$DF,$20,$BF,$7F,$6F,$90,$DF,$3F,$37,$C8,$EF,$1F
; Tile number 0x08D
.db $F8,$07,$F7,$F8,$F8,$07,$FF,$F0,$F8,$07,$EF,$F0,$E8,$07,$EF,$F0,$E1,$0E,$CF,$F0,$B1,$7E,$EF,$E0,$B0,$6E,$FE,$E1,$02,$9C,$9E,$A1
; Tile number 0x08E
.db $F0,$6F,$FF,$60,$90,$0F,$BF,$60,$81,$6E,$9F,$00,$11,$7E,$8F,$00,$B7,$B8,$EF,$60,$FF,$E0,$FF,$E0,$DF,$C1,$DE,$E0,$3F,$20,$1F,$C0
; Tile number 0x08F
.db $02,$FD,$FF,$00,$04,$FB,$FF,$00,$08,$F7,$FF,$00,$88,$77,$FF,$00,$88,$77,$FF,$00,$84,$7B,$FF,$00,$82,$7D,$FF,$00,$E1,$1E,$FF,$00
; Tile number 0x090
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$01,$FF,$FF,$01
; Tile number 0x091
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$FD,$FF,$FF,$FD
; Tile number 0x092
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$C0,$BF,$FF,$80
; Tile number 0x093
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$01,$FE,$FF,$00
; Tile number 0x094
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$0C,$F3,$FF,$00,$18,$E7,$FF,$00,$18,$E7,$FF,$00,$10,$EF,$FF,$00,$38,$C7,$FF,$00,$38,$C7,$FF,$00
; Tile number 0x095
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$04,$FB,$FF,$00,$5F,$A0,$FF,$00,$38,$C7,$FF,$00,$1C,$E3,$FF,$00,$1C,$E3,$FF,$00,$1E,$E1,$FF,$00
; Tile number 0x096
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$E0,$FF,$00,$00,$87,$F8,$00,$87,$3F,$C0,$07,$74,$BD,$E5,$13,$54,$93,$FB,$07,$38,$CF,$F7,$07
; Tile number 0x097
.db $43,$BD,$FD,$3E,$23,$FF,$DE,$1D,$10,$1D,$EE,$0E,$0C,$F9,$00,$06,$E3,$FF,$C3,$20,$2B,$CE,$CA,$F1,$03,$F0,$F1,$FF,$07,$F8,$FF,$FF
; Tile number 0x098
.db $00,$EF,$1F,$00,$00,$FB,$07,$00,$20,$FD,$23,$00,$70,$F0,$7F,$00,$00,$D0,$2F,$00,$80,$E0,$9F,$00,$A0,$3C,$23,$C0,$E8,$0F,$C8,$F0
; Tile number 0x099
.db $00,$C3,$C3,$24,$3C,$DF,$FB,$18,$18,$E7,$FF,$00,$00,$FF,$FF,$00,$01,$9E,$7F,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$80,$7F,$00
; Tile number 0x09A
.db $19,$E6,$F6,$0F,$07,$F8,$FF,$00,$01,$F8,$FF,$00,$03,$C7,$FB,$01,$02,$26,$DA,$02,$03,$06,$FA,$00,$01,$0F,$F1,$00,$00,$7D,$83,$00
; Tile number 0x09B
.db $EE,$D6,$FA,$C2,$F0,$90,$60,$0E,$AA,$AA,$2A,$6E,$81,$81,$81,$81,$05,$04,$05,$06,$CC,$C3,$CF,$F0,$C0,$BF,$7F,$00,$00,$FF,$FF,$00
; Tile number 0x09C
.db $E0,$DF,$BF,$80,$C0,$BF,$FF,$80,$00,$7F,$7F,$80,$80,$7F,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x09D
.db $18,$E7,$FF,$00,$08,$F7,$FF,$00,$0C,$F3,$FF,$00,$07,$F8,$FF,$00,$03,$FC,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x09E
.db $00,$FE,$FE,$01,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x09F
.db $71,$73,$73,$FD,$61,$EF,$EF,$71,$61,$EF,$EF,$71,$61,$EF,$EF,$71,$61,$EF,$EF,$71,$61,$EF,$EF,$71,$51,$DF,$8E,$20,$00,$FF,$FF,$00
; Tile number 0x0A0
.db $F0,$8F,$FF,$80,$F3,$F5,$F7,$F9,$B9,$BD,$9D,$DB,$FB,$9F,$FF,$9B,$FB,$9F,$FF,$9B,$FB,$9F,$FD,$99,$41,$27,$66,$98,$00,$FF,$FF,$00
; Tile number 0x0A1
.db $E0,$1F,$FF,$00,$F0,$FF,$EF,$E0,$B0,$FF,$7F,$30,$F0,$FF,$FF,$F0,$F0,$0F,$FF,$00,$E0,$EF,$EF,$F0,$C0,$DF,$DF,$E0,$00,$FF,$FF,$00
; Tile number 0x0A2
.db $02,$FD,$FF,$00,$02,$FD,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$0E,$F5,$FB,$00,$0F,$F2,$FD,$00,$0B,$F4,$FF,$00,$09,$F6,$FF,$00
; Tile number 0x0A3
.db $3C,$C3,$FF,$00,$1C,$E3,$FF,$00,$1A,$E5,$FF,$00,$0F,$F0,$FF,$00,$07,$F8,$FF,$00,$87,$78,$FF,$00,$C3,$3C,$FF,$00,$F1,$0F,$FE,$00
; Tile number 0x0A4
.db $0F,$F0,$FF,$00,$08,$F7,$FF,$00,$08,$F7,$FF,$00,$08,$F7,$FF,$00,$8C,$73,$FF,$00,$FC,$03,$FF,$00,$F8,$07,$FF,$00,$F0,$8F,$7F,$00
; Tile number 0x0A5
.db $38,$C7,$F7,$0F,$7C,$85,$F9,$03,$71,$8E,$FF,$00,$70,$8F,$FF,$00,$20,$DF,$FF,$00,$00,$FF,$FF,$00,$01,$FE,$FF,$00,$01,$FF,$FE,$00
; Tile number 0x0A6
.db $1F,$E0,$FF,$FF,$9F,$A0,$BF,$BF,$DF,$E0,$7F,$7F,$5F,$E0,$BF,$3F,$FF,$40,$9F,$3F,$AF,$30,$BE,$7F,$27,$39,$3E,$FE,$E6,$E9,$0C,$1E
; Tile number 0x0A7
.db $FD,$01,$F9,$FE,$FF,$00,$FF,$FF,$9F,$60,$9C,$FF,$1C,$EF,$04,$F0,$60,$A7,$18,$C0,$80,$83,$7C,$00,$00,$07,$F8,$00,$00,$07,$F8,$00
; Tile number 0x0A8
.db $80,$FF,$80,$00,$40,$80,$83,$FC,$E6,$19,$1B,$FC,$6C,$EB,$1B,$7C,$34,$F3,$0B,$3C,$14,$F3,$0F,$18,$1C,$FB,$0F,$10,$18,$FF,$0F,$10
; Tile number 0x0A9
.db $10,$F7,$1F,$00,$60,$1F,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0AA
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$1F,$EF,$FF,$0F,$1D,$FD,$FD,$1F
; Tile number 0x0AB
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$DE,$AF,$FF,$8E,$DF,$EE,$FF,$CE
; Tile number 0x0AC
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$7B,$F5,$FF,$71,$FF,$73,$FF,$73
; Tile number 0x0AD
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$F0,$FF,$FF,$F0,$30,$37,$37,$F8
; Tile number 0x0AE
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$10,$FF,$FF,$10,$00,$EF,$EF,$10
; Tile number 0x0AF
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$3F,$FF,$FF,$3F,$73,$F3,$F3,$7F
; Tile number 0x0B0
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$0F,$EF,$EF,$1F,$99,$D9,$59,$3F
; Tile number 0x0B1
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$80,$FF,$FF,$80,$C0,$FF,$FF,$C0
; Tile number 0x0B2
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$81,$FD,$FD,$83,$87,$FB,$FF,$83
; Tile number 0x0B3
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$E0,$EE,$EE,$F1,$39,$3D,$35,$F3
; Tile number 0x0B4
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$FC,$FB,$FF,$F8,$9C,$9F,$9F,$FC
; Tile number 0x0B5
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$07,$FF,$FB,$03,$17,$E7,$F7,$0F
; Tile number 0x0B6
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$0F,$EF,$EF,$1F,$31,$D5,$F5,$1B
; Tile number 0x0B7
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$3F,$DE,$FF,$1E,$BF,$F3,$7F,$33
; Tile number 0x0B8
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$3C,$FD,$FD,$3E,$63,$EA,$AB,$36
; Tile number 0x0B9
.db $08,$F7,$FF,$00,$08,$F7,$FF,$00,$04,$FB,$FF,$00,$0F,$F4,$FB,$00,$0F,$F0,$FF,$00,$04,$FB,$FF,$00,$03,$FC,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0BA
.db $FF,$01,$FE,$00,$7F,$81,$FE,$00,$1F,$E1,$FE,$00,$FF,$06,$F9,$00,$FF,$44,$BB,$00,$FF,$0C,$F3,$00,$FE,$09,$F7,$00,$F0,$0F,$FF,$00
; Tile number 0x0BB
.db $30,$2F,$1F,$C0,$20,$1F,$3F,$C0,$E1,$DE,$3F,$00,$E2,$1D,$FF,$00,$FC,$43,$BF,$00,$80,$7F,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0BC
.db $42,$BC,$FE,$01,$82,$7E,$FC,$01,$03,$FE,$FC,$00,$03,$FE,$FE,$00,$02,$FE,$FF,$01,$02,$FF,$FE,$00,$02,$FF,$FC,$00,$00,$FD,$FE,$00
; Tile number 0x0BD
.db $F8,$C5,$34,$0E,$F8,$85,$74,$0E,$FF,$CF,$37,$06,$74,$17,$67,$8F,$78,$0B,$73,$87,$FC,$83,$7F,$03,$FF,$BE,$54,$01,$3D,$3D,$C3,$FE
; Tile number 0x0BE
.db $00,$FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$46,$7E,$46,$81,$56,$C7,$BF,$87,$C8,$7F,$37,$87,$DA,$25,$77,$8F,$D3,$2C,$FE,$0F
; Tile number 0x0BF
.db $10,$FF,$1F,$00,$70,$EF,$3F,$40,$60,$DF,$7F,$00,$C0,$FF,$BF,$80,$40,$3F,$7F,$80,$80,$7F,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C0
.db $1F,$FC,$FF,$1C,$1F,$EF,$FF,$0F,$07,$FB,$FD,$01,$19,$FB,$FA,$1C,$1F,$FF,$FF,$1F,$0F,$FF,$F7,$07,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C1
.db $1F,$EF,$FE,$0E,$DA,$AA,$FA,$8F,$D9,$E9,$F9,$CF,$DB,$E9,$FB,$CD,$D9,$EB,$FB,$CD,$85,$F7,$72,$08,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C2
.db $7F,$73,$7F,$F3,$FB,$F5,$FF,$F1,$F8,$F7,$BF,$B0,$BF,$F7,$FB,$B3,$BB,$F7,$FF,$B3,$80,$CE,$4E,$31,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C3
.db $60,$1F,$7F,$80,$E0,$EF,$EF,$F0,$B0,$37,$B7,$78,$B8,$7F,$FF,$38,$F8,$FF,$F7,$F0,$D0,$CF,$DF,$E0,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C4
.db $10,$DF,$CF,$20,$20,$FF,$FF,$20,$20,$FF,$FF,$20,$40,$9F,$DF,$20,$20,$9F,$BF,$40,$40,$FF,$FF,$40,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C5
.db $E3,$FC,$7F,$60,$68,$70,$78,$E7,$6F,$7F,$77,$E7,$F7,$7B,$EF,$63,$3F,$BF,$BF,$7F,$2C,$CD,$ED,$1E,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C6
.db $39,$FE,$F7,$30,$38,$74,$7C,$B3,$BB,$F7,$FF,$B3,$B0,$F6,$F6,$B9,$3F,$5F,$7F,$9F,$06,$F6,$F6,$0F,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C7
.db $81,$7E,$FF,$00,$00,$3E,$3E,$C1,$C1,$FF,$FF,$C1,$C1,$FF,$FF,$C1,$C2,$FC,$FE,$C1,$81,$7C,$FD,$02,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C8
.db $07,$7F,$7B,$83,$81,$7D,$FD,$03,$01,$FE,$FF,$00,$03,$FB,$FB,$07,$07,$FB,$FF,$03,$00,$FE,$FE,$01,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0C9
.db $E3,$9F,$7F,$03,$E7,$EB,$EF,$F3,$B7,$33,$B7,$7B,$B3,$77,$F7,$3B,$FB,$F5,$FF,$F1,$C0,$DF,$DF,$E0,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0CA
.db $98,$E7,$7F,$00,$00,$C3,$C3,$3C,$BC,$7F,$FF,$3C,$8C,$EF,$EF,$9C,$FC,$FF,$FF,$FC,$68,$67,$6F,$F0,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0CB
.db $0B,$EB,$EB,$1F,$17,$EF,$FB,$03,$07,$FF,$FB,$03,$07,$FF,$FB,$03,$07,$FF,$FB,$03,$04,$F8,$FC,$03,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0CC
.db $1B,$DD,$D7,$31,$3B,$F5,$FF,$31,$1B,$DD,$D7,$31,$33,$F7,$D5,$19,$1B,$FB,$FB,$1F,$07,$F6,$F7,$0E,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0CD
.db $B3,$FF,$FF,$B3,$F3,$BF,$FF,$B3,$B3,$FF,$FF,$B3,$33,$7F,$7F,$B3,$1F,$DF,$DF,$3F,$1E,$FF,$ED,$0C,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0CE
.db $36,$BE,$AA,$63,$77,$EB,$FF,$63,$77,$EB,$FF,$63,$32,$BA,$AA,$67,$36,$F7,$F7,$3E,$08,$EB,$EB,$1C,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0CF
.db $01,$FF,$FC,$01,$02,$FE,$FF,$01,$02,$FE,$FD,$01,$02,$FC,$FF,$01,$02,$FC,$FF,$01,$01,$FF,$FE,$00,$01,$FE,$FF,$00,$FF,$3C,$D3,$00
; Tile number 0x0D0
.db $3F,$3F,$C0,$FF,$BC,$3C,$43,$7F,$BC,$3C,$43,$7F,$9C,$1C,$63,$7F,$DE,$1E,$21,$3F,$4E,$0E,$B1,$BF,$F3,$E3,$DF,$00,$C1,$BE,$7F,$00
; Tile number 0x0D1
.db $D7,$E9,$AE,$1E,$66,$59,$BD,$9E,$6E,$53,$9D,$BC,$0A,$35,$BF,$FC,$9C,$63,$7B,$7C,$9C,$E3,$FF,$F8,$38,$C7,$F7,$F8,$F8,$07,$7F,$F0
; Tile number 0x0D2
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$F8,$F8,$07,$07,$FF,$FF,$07,$07,$FF,$FF,$07
; Tile number 0x0D3
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$44,$78,$3C,$83,$F3,$EB,$FB,$E7,$33,$BB,$BB,$77
; Tile number 0x0D4
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$20,$3C,$1C,$C3,$F3,$FF,$FF,$F3,$7B,$B7,$FF,$33
; Tile number 0x0D5
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$0E,$0E,$F1,$F3,$FD,$FF,$F1,$83,$7F,$FF,$03
; Tile number 0x0D6
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$3C,$3C,$C3,$C7,$DB,$DF,$E3,$67,$7B,$7F,$E3
; Tile number 0x0D7
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$63,$63,$9C,$BC,$DF,$FF,$9C,$DC,$9F,$DF,$BC
; Tile number 0x0D8
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$10,$F0,$E0,$0F,$0F,$EF,$EF,$1F,$0C,$EF,$EF,$1C
; Tile number 0x0D9
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$40,$23,$63,$9C,$9E,$BD,$BF,$DC,$1D,$FC,$FD,$1E
; Tile number 0x0DA
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$01,$18,$19,$E6,$F7,$EF,$FE,$E6,$F7,$EF,$FE,$E6
; Tile number 0x0DB
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$40,$8C,$CC,$33,$73,$BF,$FF,$33,$73,$BF,$FF,$33
; Tile number 0x0DC
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$02,$FC,$FE,$01,$83,$7F,$FF,$03,$83,$7F,$FF,$03
; Tile number 0x0DD
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$30,$30,$CF,$CF,$FF,$FF,$CF,$C3,$DF,$DF,$E3
; Tile number 0x0DE
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$02,$13,$11,$EC,$EE,$FF,$FF,$EE,$8E,$FF,$FF,$8E
; Tile number 0x0DF
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$5C,$9F,$DB,$38,$FE,$7F,$FF,$7E,$C6,$DE,$DE,$E7
; Tile number 0x0E0
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$9C,$9C,$63,$73,$FF,$FF,$73,$73,$F7,$F7,$7B
; Tile number 0x0E1
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$04,$F8,$FC,$03,$03,$FB,$FB,$07,$03,$FB,$FB,$07
; Tile number 0x0E2
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$24,$1C,$38,$C3,$E7,$EF,$EF,$F7,$36,$BE,$BE,$77
; Tile number 0x0E3
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$22,$3C,$1E,$C1,$F7,$FB,$FF,$F3,$76,$FE,$BE,$37
; Tile number 0x0E4
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$E0,$FF,$DF,$C0,$F0,$FF,$FF,$F0,$38,$FF,$F7,$30
; Tile number 0x0E5
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$14,$8C,$98,$63,$77,$EF,$FF,$67,$76,$EE,$FE,$67
; Tile number 0x0E6
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$03,$1F,$1D,$E1,$F3,$EB,$FB,$E7,$0F,$F6,$FF,$06
; Tile number 0x0E7
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$A8,$90,$B8,$C7,$F7,$E7,$F7,$EF,$71,$FF,$EF,$61
; Tile number 0x0E8
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$0F,$0F,$F0,$F0,$FF,$FF,$F0,$C0,$BF,$FF,$80
; Tile number 0x0E9
.db $02,$FC,$FE,$01,$04,$F8,$FD,$03,$08,$F0,$FB,$07,$0F,$F8,$F0,$00,$1F,$E0,$F0,$00,$1F,$F0,$E0,$00,$2F,$C0,$E0,$10,$3F,$D0,$F0,$10
; Tile number 0x0EA
.db $3C,$3C,$C3,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$BF,$3F,$40,$7F,$E7,$07,$18,$1F,$FB,$03,$04,$07,$FD,$01,$02,$03,$FF,$00,$00,$00
; Tile number 0x0EB
.db $70,$4F,$3F,$80,$70,$4F,$FF,$80,$F0,$EF,$3F,$C0,$F0,$FF,$1F,$E0,$F8,$FF,$0F,$F0,$FC,$FF,$07,$F8,$FE,$FD,$03,$FC,$FD,$FC,$03,$FE
; Tile number 0x0EC
.db $F0,$0F,$AF,$70,$30,$CF,$DF,$20,$30,$CF,$FF,$00,$10,$EF,$FF,$00,$00,$FF,$FF,$00,$08,$F7,$FF,$00,$68,$97,$FF,$00,$64,$9B,$FF,$00
; Tile number 0x0ED
.db $07,$FF,$FF,$07,$07,$FF,$FF,$07,$07,$FF,$FF,$07,$07,$FF,$FF,$07,$00,$F8,$F8,$07,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0EE
.db $73,$BB,$FB,$37,$73,$BB,$FB,$37,$33,$BB,$BB,$77,$F3,$EB,$FB,$E7,$44,$78,$3C,$83,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0EF
.db $F3,$FF,$FF,$F3,$E3,$FF,$FF,$E3,$73,$FF,$FF,$73,$7B,$BF,$F7,$33,$20,$E4,$C4,$1B,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F0
.db $F3,$FF,$FF,$F3,$87,$8F,$8B,$F3,$87,$7F,$FF,$07,$FF,$F6,$FF,$F6,$08,$01,$09,$F6,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F1
.db $F7,$6B,$FF,$63,$E7,$6B,$EF,$73,$F7,$FB,$FF,$F3,$7F,$B3,$FF,$33,$09,$CD,$C4,$32,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F2
.db $AC,$AF,$AF,$FC,$7C,$7F,$6F,$EC,$EC,$7F,$FF,$6C,$6C,$FF,$FF,$6C,$20,$B3,$93,$4C,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F3
.db $0F,$EF,$EF,$1F,$0C,$EC,$EC,$1F,$0C,$EF,$EF,$1C,$0F,$EF,$EF,$1F,$10,$F0,$E0,$0F,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F4
.db $DA,$BA,$FA,$9F,$5F,$3B,$7F,$9B,$1B,$FF,$FF,$1B,$9B,$BF,$BF,$DB,$42,$66,$24,$99,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F5
.db $F7,$EF,$FE,$E6,$F7,$EF,$FE,$E6,$F6,$6E,$FE,$67,$77,$EF,$FB,$63,$43,$DD,$9F,$21,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F6
.db $73,$BF,$FF,$33,$73,$BF,$FF,$33,$73,$FF,$BF,$33,$E3,$EF,$EF,$F3,$E0,$FC,$DC,$C3,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F7
.db $87,$7F,$FB,$03,$86,$7E,$FE,$07,$87,$7F,$FF,$07,$E6,$E7,$E7,$FE,$12,$13,$01,$EC,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F8
.db $E3,$7F,$FF,$63,$E3,$7F,$FF,$63,$E3,$EF,$EF,$F3,$33,$BF,$BF,$73,$40,$8C,$CC,$33,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0F9
.db $8E,$FF,$FF,$8E,$8E,$FF,$FF,$8E,$8E,$FF,$FF,$8E,$8E,$FF,$FF,$8E,$02,$73,$71,$8C,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0FA
.db $C3,$FB,$FB,$C7,$C3,$FB,$FB,$C7,$C7,$DF,$DE,$E6,$FE,$7F,$FF,$7E,$5C,$9F,$DB,$38,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0FB
.db $7F,$FF,$FB,$7B,$7F,$EF,$FF,$6F,$6F,$F7,$FF,$67,$63,$FB,$FB,$67,$00,$9C,$9C,$63,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0FC
.db $03,$FB,$FB,$07,$03,$FB,$FB,$07,$03,$FB,$FB,$07,$03,$FB,$FB,$07,$04,$F8,$FC,$03,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0FD
.db $F7,$7F,$FF,$77,$F7,$EF,$FF,$E7,$C6,$3E,$FE,$07,$06,$FE,$FE,$07,$05,$FD,$F8,$02,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0FE
.db $FF,$F6,$FF,$F6,$EF,$F6,$FF,$E6,$66,$EE,$EE,$77,$77,$FB,$BF,$33,$0A,$CC,$C6,$31,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x0FF
.db $38,$FF,$FF,$38,$30,$F7,$F7,$38,$3B,$FB,$F3,$37,$F3,$FF,$FF,$F3,$E3,$FD,$DF,$C1,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x100
.db $77,$EF,$FF,$67,$77,$EF,$FF,$67,$76,$EE,$FE,$67,$E7,$FF,$FF,$E7,$84,$BC,$B8,$C3,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x101
.db $EE,$FF,$F7,$E6,$0E,$1F,$17,$E6,$0E,$F7,$FF,$06,$E3,$EB,$EB,$F7,$13,$1F,$0D,$E1,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x102
.db $01,$FF,$FF,$01,$01,$FF,$FF,$01,$61,$EF,$EF,$71,$E1,$FF,$FF,$E1,$80,$BE,$BE,$C1,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x103
.db $C0,$BF,$FF,$80,$C0,$BF,$FF,$80,$C0,$BF,$FF,$80,$C0,$BF,$FF,$80,$00,$7F,$7F,$80,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x104
.db $1F,$C0,$C0,$20,$1F,$C0,$C0,$20,$3F,$E0,$E0,$20,$7F,$A0,$E0,$20,$7F,$A0,$E0,$20,$7F,$C0,$80,$00,$5F,$C0,$80,$00,$5F,$C0,$80,$00
; Tile number 0x105
.db $FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00,$FF,$00,$00,$00
; Tile number 0x106
.db $7F,$7F,$81,$FE,$BF,$3F,$40,$7F,$DF,$1F,$20,$3F,$EF,$0F,$10,$1F,$EF,$0F,$10,$1F,$F7,$07,$08,$0F,$FF,$07,$00,$07,$FB,$03,$04,$07
; Tile number 0x107
.db $34,$CB,$FF,$00,$BC,$53,$EF,$00,$B8,$D7,$EF,$00,$90,$AF,$7F,$80,$E0,$DF,$7F,$80,$B0,$AF,$5F,$C0,$38,$37,$DF,$E0,$20,$37,$CF,$E0
; Tile number 0x108
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$07,$FF,$FB,$03,$0F,$FF,$FF,$0F,$1E,$FE,$FE,$1F,$3E,$DD,$FF,$1C
; Tile number 0x109
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$A0,$9F,$BF,$C0,$E1,$EF,$EE,$F0,$F9,$F7,$FF,$F1,$73,$F7,$F5,$79
; Tile number 0x10A
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$74,$F3,$B7,$38,$FC,$FD,$FD,$FE,$EF,$EF,$EE,$FE,$CF,$FF,$F7,$C7
; Tile number 0x10B
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$0B,$F3,$FB,$07,$1F,$FF,$FF,$1F,$1D,$DD,$DD,$3F,$3C,$FF,$FB,$38
; Tile number 0x10C
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$80,$FF,$7F,$00,$E0,$DF,$FF,$C0,$E0,$FF,$FF,$E0,$F0,$FF,$EF,$E0
; Tile number 0x10D
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$1C,$FF,$FF,$1C,$3C,$FF,$FF,$3C,$3C,$BF,$BF,$7C,$7C,$7F,$7F,$FC
; Tile number 0x10E
.db $5F,$C0,$80,$00,$1F,$80,$80,$40,$5F,$C0,$80,$00,$5F,$C0,$80,$00,$4F,$80,$C0,$00,$67,$A0,$E0,$20,$07,$C0,$C0,$20,$33,$F0,$D0,$10
; Tile number 0x10F
.db $FB,$03,$04,$07,$FC,$00,$03,$03,$FE,$00,$01,$01,$FE,$00,$01,$01,$FE,$00,$01,$01,$FE,$00,$00,$01,$FE,$00,$00,$01,$FE,$00,$00,$01
; Tile number 0x110
.db $10,$3F,$D7,$C0,$58,$7F,$9F,$C0,$0C,$6B,$9F,$80,$90,$EB,$17,$80,$94,$EB,$17,$80,$D8,$EB,$9F,$40,$70,$77,$FF,$00,$F8,$77,$DF,$20
; Tile number 0x111
.db $0C,$F7,$FB,$00,$00,$FF,$FF,$00,$00,$FE,$FE,$01,$03,$FF,$FF,$03,$0F,$F7,$FF,$07,$0F,$FF,$FF,$0F,$1F,$FF,$FF,$1F,$3F,$DF,$FF,$1F
; Tile number 0x112
.db $79,$FD,$F5,$73,$73,$7F,$7F,$F3,$E3,$EF,$EF,$F3,$C3,$DF,$DF,$E3,$C3,$BF,$FF,$83,$03,$FF,$FD,$01,$F9,$FF,$FF,$F9,$F8,$FE,$FE,$F9
; Tile number 0x113
.db $C7,$FF,$FF,$C7,$87,$BF,$BF,$C7,$87,$BF,$BF,$C7,$87,$BF,$BF,$C7,$87,$BF,$BF,$C7,$CF,$F7,$FF,$C7,$EE,$FE,$DE,$CF,$FE,$FF,$FF,$FE
; Tile number 0x114
.db $38,$FF,$FF,$38,$38,$FF,$FF,$38,$38,$FF,$FF,$38,$38,$FF,$FF,$38,$38,$FF,$FF,$38,$3C,$FB,$FF,$38,$1D,$DF,$DE,$3C,$1F,$FF,$FF,$1F
; Tile number 0x115
.db $E1,$EE,$EF,$F0,$71,$7F,$7F,$F1,$73,$7F,$7F,$F3,$77,$7F,$7F,$F7,$77,$7F,$7F,$F7,$E7,$EF,$EF,$F7,$F0,$E8,$F8,$E7,$E0,$FF,$FF,$E0
; Tile number 0x116
.db $FC,$FF,$FF,$FC,$DC,$FF,$FF,$DC,$9C,$FF,$FF,$9C,$9C,$7F,$FF,$1C,$FF,$FF,$FF,$FF,$FF,$FF,$FF,$FF,$1C,$1C,$1C,$FF,$1C,$FF,$FF,$1C
; Tile number 0x117
.db $10,$F0,$F0,$10,$10,$F0,$E0,$00,$0A,$FA,$F2,$06,$02,$FE,$FC,$01,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x118
.db $0F,$00,$00,$00,$03,$00,$00,$00,$00,$00,$00,$00,$C0,$C0,$C0,$C0,$71,$81,$F1,$0F,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x119
.db $FF,$01,$01,$01,$FF,$01,$01,$01,$01,$01,$01,$01,$00,$00,$00,$00,$00,$00,$00,$01,$3E,$DD,$E3,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x11A
.db $E0,$6F,$DF,$20,$E0,$7F,$9F,$00,$C0,$BF,$7F,$00,$00,$7F,$7F,$80,$80,$7F,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x11B
.db $1F,$DF,$DF,$3F,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x11C
.db $F8,$FF,$FF,$F8,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x11D
.db $FC,$FF,$7F,$7C,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x11E
.db $07,$F7,$F7,$0F,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x11F
.db $80,$BF,$BF,$C0,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x120
.db $1C,$FF,$FF,$1C,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00

; Tile number 0x121
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$01,$FD,$FE,$01,$0F,$FF,$F8,$07,$3F,$FF,$E0,$1F
; Tile number 0x122
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$1F,$DF,$E0,$1F,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF
; Tile number 0x123
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$F4,$F3,$0F,$F0,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF,$FF,$FF,$00,$FF
; Tile number 0x124
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$C0,$BF,$FF,$00,$F0,$FF,$1F,$E0,$FC,$FF,$07,$F8
; Tile number 0x125
.db $00,$FF,$FF,$00,$01,$FF,$FE,$01,$03,$FB,$FC,$03,$07,$F7,$F8,$07,$0F,$EF,$F0,$0F,$1F,$DF,$E0,$1F,$3E,$BE,$C1,$3E,$7C,$FD,$83,$7C
; Tile number 0x126
.db $FF,$FF,$80,$7F,$FF,$FF,$01,$FE,$F8,$FB,$07,$F8,$E0,$EF,$1F,$E0,$80,$BF,$7F,$80,$00,$7F,$FF,$00,$00,$FF,$FF,$00,$01,$FD,$FE,$01
; Tile number 0x127
.db $F8,$F8,$0F,$F0,$00,$7F,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$18,$D9,$FF,$00,$FF,$FF,$80,$7F,$FF,$FF,$00,$FF
; Tile number 0x128
.db $7F,$7F,$80,$7F,$0B,$F3,$FE,$01,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$E0,$EF,$3F,$C0,$FE,$FF,$03,$FC
; Tile number 0x129
.db $FE,$FE,$01,$FE,$FF,$FF,$00,$FF,$7F,$7F,$C0,$3F,$0F,$EF,$F0,$0F,$07,$FF,$FC,$03,$01,$FD,$FE,$01,$00,$FF,$FF,$00,$00,$FF,$FF,$00
; Tile number 0x12A
.db $00,$FF,$FF,$00,$80,$FF,$7F,$80,$E0,$DF,$3F,$C0,$E0,$EF,$1F,$E0,$F0,$F7,$0F,$F0,$FC,$FB,$07,$F8,$FE,$FD,$03,$FC,$7E,$FF,$81,$7E
; Tile number 0x12B
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$E0,$E0,$00,$00,$E0,$E0,$00,$00,$E0,$E0,$00
; Tile number 0x12C
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
; Tile number 0x12D
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$21,$1E,$1E,$00,$00,$0C,$0C,$00,$00,$0C,$0C,$00
; Tile number 0x12E
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$0C,$F3,$FF,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00
; Tile number 0x12F
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$07,$07,$00,$00,$06,$06,$00,$00,$06,$06,$00
; Tile number 0x130
.db $00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$FF,$FF,$00,$00,$06,$06,$00,$00,$06,$06,$00,$00,$06,$06,$00

Tiles_end:
Tiles_size: .dw Tiles_end-Tiles

.BANK 1 SLOT 1
.ORG $0000

.BANK 1 SLOT 1
.ORG $0000

Tile_Numbers:
.dw $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0121,$0122,$0123,$0124,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0125,$0126,$0127,$0128,$0129,$012A,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$012B,$012C,$012D,$012E,$012F,$012C,$0130,$0011,$0012,$0013,$0014,$0015,$0016,$0017,$0018,$0019,$001A,$001B,$001C,$012C,$001D,$012C,$001E,$001F,$0020,$0021,$012C,$0022,$0023,$0000
.dw $0000,$0000,$0024,$0000,$0025,$0026,$0027,$0028,$0029,$002A,$002B,$002A,$002C,$002D,$002E,$002F,$0030,$0031,$0032,$0033,$0034,$0035,$0036,$0035,$0034,$0037,$0237,$0038,$0039,$022A,$002A,$0000
.dw $0000,$0000,$003A,$003B,$003C,$003D,$003E,$003F,$0040,$0041,$0042,$0043,$0044,$0045,$0046,$0047,$0048,$0049,$004A,$004B,$004C,$004D,$004E,$004F,$0050,$0051,$0251,$0052,$0053,$0611,$0411,$0000
.dw $0000,$0000,$0054,$0055,$0056,$0057,$0058,$0059,$005A,$005B,$0000,$0000,$005C,$005D,$005E,$005F,$0060,$0061,$0062,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$0000,$0063,$0064,$0065,$0066,$0067,$0068,$0069,$006A,$0000,$006B,$006C,$006D,$006E,$006F,$0070,$0071,$0072,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0073,$0074,$0075,$0076,$0077,$0078,$0079,$0068,$007A,$007B,$0000,$007C,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$007D,$007E,$007F,$0077,$0080,$0081,$0082,$0083,$0084,$0085,$0086,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$0000,$0087,$0088,$0089,$008A,$008B,$008C,$008D,$008E,$008F,$0000,$0000,$0000,$0000,$0090,$0091,$0092,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0093,$0094,$0095,$0096,$0097,$0098,$0099,$009A,$009B,$009C,$009D,$0273,$0000,$0000,$0000,$009E,$009F,$00A0,$00A1,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$00A2,$00A3,$00A4,$00A5,$00A6,$00A7,$00A8,$00A9,$0000,$0000,$00AA,$00AB,$00AC,$00AD,$00AE,$00AF,$00B0,$00B1,$00B2,$00B3,$00B4,$00B5,$00B6,$00B7,$00B8,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$00B9,$00BA,$00BB,$00BC,$00BD,$00BE,$00BF,$0000,$0000,$0000,$00C0,$00C1,$00C2,$00C3,$00C4,$00C5,$00C6,$00C7,$00C8,$00C9,$00CA,$00CB,$00CC,$00CD,$00CE,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$0000,$0000,$00CF,$00D0,$00D1,$00D2,$00D3,$00D4,$00D5,$00D6,$00D7,$00D8,$00D9,$00DA,$00DB,$00DC,$00DD,$00DE,$00DF,$00E0,$00E1,$00E2,$00E3,$00E4,$00E5,$00E6,$00E7,$00E8,$0000,$0000
.dw $0000,$0000,$0000,$00E9,$00EA,$00EB,$00EC,$00ED,$00EE,$00EF,$00F0,$00F1,$00F2,$00F3,$00F4,$00F5,$00F6,$00F7,$00F8,$00F9,$00FA,$00FB,$00FC,$00FD,$00FE,$00FF,$0100,$0101,$0102,$0103,$0000,$0000
.dw $0000,$0000,$0000,$0104,$0105,$0106,$0107,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0108,$0109,$010A,$010B,$010C,$010D,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$0000,$010E,$0105,$010F,$0110,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0111,$0112,$0113,$0114,$0115,$0116,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
.dw $0000,$0000,$0000,$0117,$0118,$0119,$011A,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$011B,$011C,$011D,$011E,$011F,$0120,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
;.dw $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
;.dw $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
;.dw $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000
;.dw $0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000,$0000

Sprites_Move_Table:

.db 120,140,128,140,120,148,128,148 ; S
.db 132,140,140,140,132,148,140,148 ; E
.db 144,140,152,140,144,148,152,148 ; G
.db 156,140,164,140,156,148,164,148 ; A

.db 121,141,129,141,121,149,129,149 ; S
.db 133,141,141,141,133,149,141,149 ; E
.db 145,141,153,141,145,149,153,149 ; G
.db 157,141,165,141,157,149,165,149 ; A

.db 122,142,130,142,122,150,130,150 ; S
.db 134,142,142,142,134,150,142,150 ; E
.db 146,142,154,142,146,150,154,150 ; G
.db 158,142,166,142,158,150,166,150 ; A

.db 123,143,131,143,123,151,131,151 ; S
.db 135,143,143,143,135,151,143,151 ; E
.db 147,143,155,143,147,151,155,151 ; G
.db 159,143,167,143,159,151,167,151 ; A

.db 124,144,132,144,124,152,132,152 ; S
.db 136,144,144,144,136,152,144,152 ; E
.db 148,144,156,144,148,152,156,152 ; G
.db 160,144,168,144,160,152,168,152 ; A

.db 125,145,133,145,125,153,133,153 ; S
.db 137,145,145,145,137,153,145,153 ; E
.db 149,145,157,145,149,153,157,153 ; G
.db 161,145,169,145,161,153,169,153 ; A

.db 126,145,134,145,126,153,134,153 ; S
.db 138,145,146,145,138,153,146,153 ; E
.db 150,145,158,145,150,153,158,153 ; G
.db 162,145,170,145,162,153,170,153 ; A

.db 127,145,135,145,127,153,135,153 ; S
.db 139,145,147,145,139,153,147,153 ; E
.db 151,145,159,145,151,153,159,153 ; G
.db 163,145,171,145,163,153,171,153 ; A

.db 127,146,135,146,127,154,135,154 ; S
.db 139,146,147,146,139,154,147,154 ; E
.db 151,146,159,146,151,154,159,154 ; G
.db 163,146,171,146,163,154,171,154 ; A

.db 128,146,136,146,128,154,136,154 ; S
.db 140,146,148,146,140,154,148,154 ; E
.db 152,146,160,146,152,154,160,154 ; G
.db 164,146,172,146,164,154,172,154 ; A

.db 128,147,136,147,128,155,136,155 ; S
.db 140,147,148,147,140,155,148,155 ; E
.db 152,147,160,147,152,155,160,155 ; G
.db 164,147,172,147,164,155,172,155 ; A

.db 129,147,137,147,129,155,137,155 ; S
.db 141,147,149,147,141,155,149,155 ; E
.db 153,147,161,147,153,155,161,155 ; G
.db 165,147,173,147,165,155,173,155 ; A

.db 130,148,138,148,130,156,138,156 ; S
.db 142,148,150,148,142,156,150,156 ; E
.db 154,148,162,148,154,156,162,156 ; G
.db 166,148,174,148,166,156,174,156 ; A

.db 131,149,139,149,131,157,139,157 ; S
.db 143,149,151,149,143,157,151,157 ; E
.db 155,149,163,149,155,157,163,157 ; G
.db 167,149,175,149,167,157,175,157 ; A

.db 132,150,140,150,132,158,140,158 ; S
.db 144,150,152,150,144,158,152,158 ; E
.db 156,150,164,150,156,158,164,158 ; G
.db 168,150,176,150,168,158,176,158 ; A

.db 133,151,141,151,133,159,141,159 ; S
.db 145,151,153,151,145,159,153,159 ; E
.db 157,151,165,151,157,159,165,159 ; G
.db 169,151,177,151,169,159,177,159 ; A

.db 134,152,142,152,134,160,142,160 ; S
.db 146,152,154,152,146,160,154,160 ; E
.db 158,152,166,152,158,160,166,160 ; G
.db 170,152,178,152,170,160,178,160 ; A

.db 135,153,143,153,135,161,143,161 ; S
.db 147,153,155,153,147,161,155,161 ; E
.db 159,153,167,153,159,161,167,161 ; G
.db 171,153,179,153,171,161,179,161 ; A

.db 136,154,144,154,136,162,144,162 ; S
.db 148,154,156,154,148,162,156,162 ; E
.db 160,154,168,154,160,162,168,162 ; G
.db 172,154,180,154,172,162,180,162 ; A

.db 137,154,145,154,137,162,145,162 ; S
.db 149,154,157,154,149,162,157,162 ; E
.db 161,154,169,154,161,162,169,162 ; G
.db 173,154,181,154,173,162,181,162 ; A

.db 138,154,146,154,138,162,146,162 ; S
.db 150,154,158,154,150,162,158,162 ; E
.db 162,154,170,154,162,162,170,162 ; G
.db 174,154,182,154,174,162,182,162 ; A

.db 139,154,147,154,139,162,147,162 ; S
.db 151,154,159,154,151,162,159,162 ; E
.db 163,154,171,154,163,162,171,162 ; G
.db 175,154,183,154,175,162,183,162 ; A

.db 140,154,148,154,140,162,148,162 ; S
.db 152,154,160,154,152,162,160,162 ; E
.db 164,154,172,154,164,162,172,162 ; G
.db 176,154,184,154,176,162,184,162 ; A

.db 141,154,149,154,141,162,149,162 ; S
.db 153,154,161,154,153,162,161,162 ; E
.db 165,154,173,154,165,162,173,162 ; G
.db 177,154,185,154,177,162,185,162 ; A

.db 142,154,150,154,142,162,150,162 ; S
.db 154,154,162,154,154,162,162,162 ; E
.db 166,154,174,154,166,162,174,162 ; G
.db 178,154,186,154,178,162,186,162 ; A

.db 143,154,151,154,143,162,151,162 ; S
.db 155,154,163,154,155,162,163,162 ; E
.db 167,154,175,154,167,162,175,162 ; G
.db 179,154,187,154,179,162,187,162 ; A

.db 144,153,152,153,144,161,152,161 ; S
.db 156,153,164,153,156,161,164,161 ; E
.db 168,153,176,153,168,161,176,161 ; G
.db 180,153,188,153,180,161,188,161 ; A

.db 145,152,153,152,145,160,153,160 ; S
.db 157,152,165,152,157,160,165,160 ; E
.db 169,152,177,152,169,160,177,160 ; G
.db 181,152,189,152,181,160,189,160 ; A

.db 146,151,154,151,146,159,154,159 ; S
.db 158,151,166,151,158,159,166,159 ; E
.db 170,151,178,151,170,159,178,159 ; G
.db 182,151,190,151,182,159,190,159 ; A

.db 147,150,155,150,147,158,155,158 ; S
.db 159,150,167,150,159,158,167,158 ; E
.db 171,150,179,150,171,158,179,158 ; G
.db 183,150,191,150,183,158,191,158 ; A

.db 148,149,156,149,148,157,156,157 ; S
.db 160,149,168,149,160,157,168,157 ; E
.db 172,149,180,149,172,157,180,157 ; G
.db 184,149,192,149,184,157,192,157 ; A

.db 149,148,157,148,149,156,157,156 ; S
.db 161,148,169,148,161,156,169,156 ; E
.db 173,148,181,148,173,156,181,156 ; G
.db 185,148,193,148,185,156,193,156 ; A

.db 150,147,158,147,150,155,158,155 ; S
.db 162,147,170,147,162,155,170,155 ; E
.db 174,147,182,147,174,155,182,155 ; G
.db 186,147,194,147,186,155,194,155 ; A

.db 151,146,159,146,151,154,159,154 ; S
.db 163,146,171,146,163,154,171,154 ; E
.db 175,146,183,146,175,154,183,154 ; G
.db 187,146,195,146,187,154,195,154 ; A

.db 152,145,160,145,152,153,160,153 ; S
.db 164,145,172,145,164,153,172,153 ; E
.db 176,145,184,145,176,153,184,153 ; G
.db 188,145,196,145,188,153,196,153 ; A

.db 152,144,160,144,152,152,160,152 ; S
.db 164,144,172,144,164,152,172,152 ; E
.db 176,144,184,144,176,152,184,152 ; G
.db 188,144,196,144,188,152,196,152 ; A

.db 152,143,160,143,152,151,160,151 ; S
.db 164,143,172,143,164,151,172,151 ; E
.db 176,143,184,143,176,151,184,151 ; G
.db 188,143,196,143,188,151,196,151 ; A

.db 152,142,160,142,152,150,160,150 ; S
.db 164,142,172,142,164,150,172,150 ; E
.db 176,142,184,142,176,150,184,150 ; G
.db 188,142,196,142,188,150,196,150 ; A

.db 152,141,160,141,152,149,160,149 ; S
.db 164,141,172,141,164,149,172,149 ; E
.db 176,141,184,141,176,149,184,149 ; G
.db 188,141,196,141,188,149,196,149 ; A

.db 152,140,160,140,152,148,160,148 ; S
.db 164,140,172,140,164,148,172,148 ; E
.db 176,140,184,140,176,148,184,148 ; G
.db 188,140,196,140,188,148,196,148 ; A

.db 153,139,161,139,153,147,161,147 ; S
.db 165,139,173,139,165,147,173,147 ; E
.db 177,139,185,139,177,147,185,147 ; G
.db 189,139,197,139,189,147,197,147 ; A

.db 154,138,162,138,154,146,162,146 ; S
.db 166,138,174,138,166,146,174,146 ; E
.db 178,138,186,138,178,146,186,146 ; G
.db 190,138,198,138,190,146,198,146 ; A

.db 155,137,163,137,155,145,163,145 ; S
.db 167,137,175,137,167,145,175,145 ; E
.db 179,137,187,137,179,145,187,145 ; G
.db 191,137,199,137,191,145,199,145 ; A

.db 156,136,164,136,156,144,164,144 ; S
.db 168,136,176,136,168,144,176,144 ; E
.db 180,136,188,136,180,144,188,144 ; G
.db 192,136,200,136,192,144,200,144 ; A

.db 157,135,165,135,157,143,165,143 ; S
.db 169,135,177,135,169,143,177,143 ; E
.db 181,135,189,135,181,143,189,143 ; G
.db 193,135,201,135,193,143,201,143 ; A

.db 158,134,166,134,158,142,166,142 ; S
.db 170,134,178,134,170,142,178,142 ; E
.db 182,134,190,134,182,142,190,142 ; G
.db 194,134,202,134,194,142,202,142 ; A

.db 158,133,166,133,158,141,166,141 ; S
.db 170,133,178,133,170,141,178,141 ; E
.db 182,133,190,133,182,141,190,141 ; G
.db 194,133,202,133,194,141,202,141 ; A

.db 158,132,166,132,158,140,166,140 ; S
.db 170,132,178,132,170,140,178,140 ; E
.db 182,132,190,132,182,140,190,140 ; G
.db 194,132,202,132,194,140,202,140 ; A

.db 158,131,166,131,158,139,166,139 ; S
.db 170,131,178,131,170,139,178,139 ; E
.db 182,131,190,131,182,139,190,139 ; G
.db 194,131,202,131,194,139,202,139 ; A

.db 158,130,166,130,158,138,166,138 ; S
.db 170,130,178,130,170,138,178,138 ; E
.db 182,130,190,130,182,138,190,138 ; G
.db 194,130,202,130,194,138,202,138 ; A

.db 158,129,166,129,158,137,166,137 ; S
.db 170,129,178,129,170,137,178,137 ; E
.db 182,129,190,129,182,137,190,137 ; G
.db 194,129,202,129,194,137,202,137 ; A

.db 158,128,166,128,158,136,166,136 ; S
.db 170,128,178,128,170,136,178,136 ; E
.db 182,128,190,128,182,136,190,136 ; G
.db 194,128,202,128,194,136,202,136 ; A

.db 157,126,165,126,157,134,165,134 ; S
.db 169,126,177,126,169,134,177,134 ; E
.db 181,126,189,126,181,134,189,134 ; G
.db 193,126,201,126,193,134,201,134 ; A

.db 156,125,164,125,156,133,164,133 ; S
.db 168,125,176,125,168,133,176,133 ; E
.db 180,125,188,125,180,133,188,133 ; G
.db 192,125,200,125,192,133,200,133 ; A

.db 155,124,163,124,155,132,163,132 ; S
.db 167,124,175,124,167,132,175,132 ; E
.db 179,124,187,124,179,132,187,132 ; G
.db 191,124,199,124,191,132,199,132 ; A

.db 155,123,163,123,155,131,163,131 ; S
.db 167,123,175,123,167,131,175,131 ; E
.db 179,123,187,123,179,131,187,131 ; G
.db 191,123,199,123,191,131,199,131 ; A

.db 155,122,163,122,155,130,163,130 ; S
.db 167,122,175,122,167,130,175,130 ; E
.db 179,122,187,122,179,130,187,130 ; G
.db 191,122,199,122,191,130,199,130 ; A

.db 155,121,163,121,155,129,163,129 ; S
.db 167,121,175,121,167,129,175,129 ; E
.db 179,121,187,121,179,129,187,129 ; G
.db 191,121,199,121,191,129,199,129 ; A

.db 155,120,163,120,155,128,163,128 ; S
.db 167,120,175,120,167,128,175,128 ; E
.db 179,120,187,120,179,128,187,128 ; G
.db 191,120,199,120,191,128,199,128 ; A

.db 155,119,163,119,155,127,163,127 ; S
.db 167,119,175,119,167,127,175,127 ; E
.db 179,119,187,119,179,127,187,127 ; G
.db 191,119,199,119,191,127,199,127 ; A

.db 155,118,163,118,155,126,163,126 ; S
.db 167,118,175,118,167,126,175,126 ; E
.db 179,118,187,118,179,126,187,126 ; G
.db 191,118,199,118,191,126,199,126 ; A

.db 155,117,163,117,155,125,163,125 ; S
.db 167,117,175,117,167,125,175,125 ; E
.db 179,117,187,117,179,125,187,125 ; G
.db 191,117,199,117,191,125,199,125 ; A

.db 155,116,163,116,155,124,163,124 ; S
.db 167,116,175,116,167,124,175,124 ; E
.db 179,116,187,116,179,124,187,124 ; G
.db 191,116,199,116,191,124,199,124 ; A

.db 155,115,163,115,155,123,163,123 ; S
.db 167,115,175,115,167,123,175,123 ; E
.db 179,115,187,115,179,123,187,123 ; G
.db 191,115,199,115,191,123,199,123 ; A

.db 155,114,163,114,155,122,163,122 ; S
.db 167,114,175,114,167,122,175,122 ; E
.db 179,114,187,114,179,122,187,122 ; G
.db 191,114,199,114,191,122,199,122 ; A

.db 155,113,163,113,155,121,163,121 ; S
.db 167,113,175,113,167,121,175,121 ; E
.db 179,113,187,113,179,121,187,121 ; G
.db 191,113,199,113,191,121,199,121 ; A

.db 154,111,162,111,154,119,162,119 ; S
.db 166,111,174,111,166,119,174,119 ; E
.db 178,111,186,111,178,119,186,119 ; G
.db 190,111,198,111,190,119,198,119 ; A

.db 153,110,161,110,153,118,161,118 ; S
.db 165,110,173,110,165,118,173,118 ; E
.db 177,110,185,110,177,118,185,118 ; G
.db 189,110,197,110,189,118,197,118 ; A

.db 152,109,160,109,152,117,160,117 ; S
.db 164,109,172,109,164,117,172,117 ; E
.db 176,109,184,109,176,117,184,117 ; G
.db 188,109,196,109,188,117,196,117 ; A

.db 151,109,159,109,151,117,159,117 ; S
.db 163,109,171,109,163,117,171,117 ; E
.db 175,109,183,109,175,117,183,117 ; G
.db 187,109,195,109,187,117,195,117 ; A

.db 150,109,158,109,150,117,158,117 ; S
.db 162,109,170,109,162,117,170,117 ; E
.db 174,109,182,109,174,117,182,117 ; G
.db 186,109,194,109,186,117,194,117 ; A

.db 149,109,157,109,149,117,157,117 ; S
.db 161,109,169,109,161,117,169,117 ; E
.db 173,109,181,109,173,117,181,117 ; G
.db 185,109,193,109,185,117,193,117 ; A

.db 148,109,156,109,148,117,156,117 ; S
.db 160,109,168,109,160,117,168,117 ; E
.db 172,109,180,109,172,117,180,117 ; G
.db 184,109,192,109,184,117,192,117 ; A

.db 147,109,155,109,147,117,155,117 ; S
.db 159,109,167,109,159,117,167,117 ; E
.db 171,109,179,109,171,117,179,117 ; G
.db 183,109,191,109,183,117,191,117 ; A

.db 146,109,154,109,146,117,154,117 ; S
.db 158,109,166,109,158,117,166,117 ; E
.db 170,109,178,109,170,117,178,117 ; G
.db 182,109,190,109,182,117,190,117 ; A

.db 145,109,153,109,145,117,153,117 ; S
.db 157,109,165,109,157,117,165,117 ; E
.db 169,109,177,109,169,117,177,117 ; G
.db 181,109,189,109,181,117,189,117 ; A

.db 144,109,152,109,144,117,152,117 ; S
.db 156,109,164,109,156,117,164,117 ; E
.db 168,109,176,109,168,117,176,117 ; G
.db 180,109,188,109,180,117,188,117 ; A

.db 143,109,151,109,143,117,151,117 ; S
.db 155,109,163,109,155,117,163,117 ; E
.db 167,109,175,109,167,117,175,117 ; G
.db 179,109,187,109,179,117,187,117 ; A

.db 142,109,150,109,142,117,150,117 ; S
.db 154,109,162,109,154,117,162,117 ; E
.db 166,109,174,109,166,117,174,117 ; G
.db 178,109,186,109,178,117,186,117 ; A

.db 141,109,149,109,141,117,149,117 ; S
.db 153,109,161,109,153,117,161,117 ; E
.db 165,109,173,109,165,117,173,117 ; G
.db 177,109,185,109,177,117,185,117 ; A

.db 140,109,148,109,140,117,148,117 ; S
.db 152,109,160,109,152,117,160,117 ; E
.db 164,109,172,109,164,117,172,117 ; G
.db 176,109,184,109,176,117,184,117 ; A

.db 139,109,147,109,139,117,147,117 ; S
.db 151,109,159,109,151,117,159,117 ; E
.db 163,109,171,109,163,117,171,117 ; G
.db 175,109,183,109,175,117,183,117 ; A

.db 137,109,145,109,137,117,145,117 ; S
.db 149,109,157,109,149,117,157,117 ; E
.db 161,109,169,109,161,117,169,117 ; G
.db 173,109,181,109,173,117,181,117 ; A

.db 136,109,144,109,136,117,144,117 ; S
.db 148,109,156,109,148,117,156,117 ; E
.db 160,109,168,109,160,117,168,117 ; G
.db 172,109,180,109,172,117,180,117 ; A

.db 135,109,143,109,135,117,143,117 ; S
.db 147,109,155,109,147,117,155,117 ; E
.db 159,109,167,109,159,117,167,117 ; G
.db 171,109,179,109,171,117,179,117 ; A

.db 134,109,142,109,134,117,142,117 ; S
.db 146,109,154,109,146,117,154,117 ; E
.db 158,109,166,109,158,117,166,117 ; G
.db 170,109,178,109,170,117,178,117 ; A

.db 133,109,141,109,133,117,141,117 ; S
.db 145,109,153,109,145,117,153,117 ; E
.db 157,109,165,109,157,117,165,117 ; G
.db 169,109,177,109,169,117,177,117 ; A

.db 132,109,140,109,132,117,140,117 ; S
.db 144,109,152,109,144,117,152,117 ; E
.db 156,109,164,109,156,117,164,117 ; G
.db 168,109,176,109,168,117,176,117 ; A

.db 131,109,139,109,131,117,139,117 ; S
.db 143,109,151,109,143,117,151,117 ; E
.db 155,109,163,109,155,117,163,117 ; G
.db 167,109,175,109,167,117,175,117 ; A

.db 130,109,138,109,130,117,138,117 ; S
.db 142,109,150,109,142,117,150,117 ; E
.db 154,109,162,109,154,117,162,117 ; G
.db 166,109,174,109,166,117,174,117 ; A

.db 129,109,137,109,129,117,137,117 ; S
.db 141,109,149,109,141,117,149,117 ; E
.db 153,109,161,109,153,117,161,117 ; G
.db 165,109,173,109,165,117,173,117 ; A

.db 128,108,136,108,128,116,136,116 ; S
.db 140,108,148,108,140,116,148,116 ; E
.db 152,108,160,108,152,116,160,116 ; G
.db 164,108,172,108,164,116,172,116 ; A

.db 127,107,135,107,127,115,135,115 ; S
.db 139,107,147,107,139,115,147,115 ; E
.db 151,107,159,107,151,115,159,115 ; G
.db 163,107,171,107,163,115,171,115 ; A

.db 126,106,134,106,126,114,134,114 ; S
.db 138,106,146,106,138,114,146,114 ; E
.db 150,106,158,106,150,114,158,114 ; G
.db 162,106,170,106,162,114,170,114 ; A

.db 125,105,133,105,125,113,133,113 ; S
.db 137,105,145,105,137,113,145,113 ; E
.db 149,105,157,105,149,113,157,113 ; G
.db 161,105,169,105,161,113,169,113 ; A

.db 124,104,132,104,124,112,132,112 ; S
.db 136,104,144,104,136,112,144,112 ; E
.db 148,104,156,104,148,112,156,112 ; G
.db 160,104,168,104,160,112,168,112 ; A

.db 123,103,131,103,123,111,131,111 ; S
.db 135,103,143,103,135,111,143,111 ; E
.db 147,103,155,103,147,111,155,111 ; G
.db 159,103,167,103,159,111,167,111 ; A

.db 122,102,130,102,122,110,130,110 ; S
.db 134,102,142,102,134,110,142,110 ; E
.db 146,102,154,102,146,110,154,110 ; G
.db 158,102,166,102,158,110,166,110 ; A

.db 121,101,129,101,121,109,129,109 ; S
.db 133,101,141,101,133,109,141,109 ; E
.db 145,101,153,101,145,109,153,109 ; G
.db 157,101,165,101,157,109,165,109 ; A

.db 120,100,128,100,120,108,128,108 ; S
.db 132,100,140,100,132,108,140,108 ; E
.db 144,100,152,100,144,108,152,108 ; G
.db 156,100,164,100,156,108,164,108 ; A

.db 119,99,127,99,119,107,127,107 ; S
.db 131,99,139,99,131,107,139,107 ; E
.db 143,99,151,99,143,107,151,107 ; G
.db 155,99,163,99,155,107,163,107 ; A

.db 118,98,126,98,118,106,126,106 ; S
.db 130,98,138,98,130,106,138,106 ; E
.db 142,98,150,98,142,106,150,106 ; G
.db 154,98,162,98,154,106,162,106 ; A

.db 117,97,125,97,117,105,125,105 ; S
.db 129,97,137,97,129,105,137,105 ; E
.db 141,97,149,97,141,105,149,105 ; G
.db 153,97,161,97,153,105,161,105 ; A

.db 116,96,124,96,116,104,124,104 ; S
.db 128,96,136,96,128,104,136,104 ; E
.db 140,96,148,96,140,104,148,104 ; G
.db 152,96,160,96,152,104,160,104 ; A

.db 115,95,123,95,115,103,123,103 ; S
.db 127,95,135,95,127,103,135,103 ; E
.db 139,95,147,95,139,103,147,103 ; G
.db 151,95,159,95,151,103,159,103 ; A

.db 114,94,122,94,114,102,122,102 ; S
.db 126,94,134,94,126,102,134,102 ; E
.db 138,94,146,94,138,102,146,102 ; G
.db 150,94,158,94,150,102,158,102 ; A

.db 113,93,121,93,113,101,121,101 ; S
.db 125,93,133,93,125,101,133,101 ; E
.db 137,93,145,93,137,101,145,101 ; G
.db 149,93,157,93,149,101,157,101 ; A

.db 112,92,120,92,112,100,120,100 ; S
.db 124,92,132,92,124,100,132,100 ; E
.db 136,92,144,92,136,100,144,100 ; G
.db 148,92,156,92,148,100,156,100 ; A

.db 111,91,119,91,111,99,119,99 ; S
.db 123,91,131,91,123,99,131,99 ; E
.db 135,91,143,91,135,99,143,99 ; G
.db 147,91,155,91,147,99,155,99 ; A

.db 110,90,118,90,110,98,118,98 ; S
.db 122,90,130,90,122,98,130,98 ; E
.db 134,90,142,90,134,98,142,98 ; G
.db 146,90,154,90,146,98,154,98 ; A

.db 109,89,117,89,109,97,117,97 ; S
.db 121,89,129,89,121,97,129,97 ; E
.db 133,89,141,89,133,97,141,97 ; G
.db 145,89,153,89,145,97,153,97 ; A

.db 108,88,116,88,108,96,116,96 ; S
.db 120,88,128,88,120,96,128,96 ; E
.db 132,88,140,88,132,96,140,96 ; G
.db 144,88,152,88,144,96,152,96 ; A

.db 107,87,115,87,107,95,115,95 ; S
.db 119,87,127,87,119,95,127,95 ; E
.db 131,87,139,87,131,95,139,95 ; G
.db 143,87,151,87,143,95,151,95 ; A

.db 106,87,114,87,106,95,114,95 ; S
.db 118,87,126,87,118,95,126,95 ; E
.db 130,87,138,87,130,95,138,95 ; G
.db 142,87,150,87,142,95,150,95 ; A

.db 105,87,113,87,105,95,113,95 ; S
.db 117,87,125,87,117,95,125,95 ; E
.db 129,87,137,87,129,95,137,95 ; G
.db 141,87,149,87,141,95,149,95 ; A

.db 104,87,112,87,104,95,112,95 ; S
.db 116,87,124,87,116,95,124,95 ; E
.db 128,87,136,87,128,95,136,95 ; G
.db 140,87,148,87,140,95,148,95 ; A

.db 103,87,111,87,103,95,111,95 ; S
.db 115,87,123,87,115,95,123,95 ; E
.db 127,87,135,87,127,95,135,95 ; G
.db 139,87,147,87,139,95,147,95 ; A

.db 102,87,110,87,102,95,110,95 ; S
.db 114,87,122,87,114,95,122,95 ; E
.db 126,87,134,87,126,95,134,95 ; G
.db 138,87,146,87,138,95,146,95 ; A

.db 101,87,109,87,101,95,109,95 ; S
.db 113,87,121,87,113,95,121,95 ; E
.db 125,87,133,87,125,95,133,95 ; G
.db 137,87,145,87,137,95,145,95 ; A

.db 100,87,108,87,100,95,108,95 ; S
.db 112,87,120,87,112,95,120,95 ; E
.db 124,87,132,87,124,95,132,95 ; G
.db 136,87,144,87,136,95,144,95 ; A

.db 99,86,107,86,99,94,107,94 ; S
.db 111,86,119,86,111,94,119,94 ; E
.db 123,86,131,86,123,94,131,94 ; G
.db 135,86,143,86,135,94,143,94 ; A

.db 98,87,106,87,98,95,106,95 ; S
.db 110,87,118,87,110,95,118,95 ; E
.db 122,87,130,87,122,95,130,95 ; G
.db 134,87,142,87,134,95,142,95 ; A

.db 97,88,105,88,97,96,105,96 ; S
.db 109,88,117,88,109,96,117,96 ; E
.db 121,88,129,88,121,96,129,96 ; G
.db 133,88,141,88,133,96,141,96 ; A

.db 96,89,104,89,96,97,104,97 ; S
.db 108,89,116,89,108,97,116,97 ; E
.db 120,89,128,89,120,97,128,97 ; G
.db 132,89,140,89,132,97,140,97 ; A

.db 95,90,103,90,95,98,103,98 ; S
.db 107,90,115,90,107,98,115,98 ; E
.db 119,90,127,90,119,98,127,98 ; G
.db 131,90,139,90,131,98,139,98 ; A

.db 94,91,102,91,94,99,102,99 ; S
.db 106,91,114,91,106,99,114,99 ; E
.db 118,91,126,91,118,99,126,99 ; G
.db 130,91,138,91,130,99,138,99 ; A

.db 94,92,102,92,94,100,102,100 ; S
.db 106,92,114,92,106,100,114,100 ; E
.db 118,92,126,92,118,100,126,100 ; G
.db 130,92,138,92,130,100,138,100 ; A

.db 94,93,102,93,94,101,102,101 ; S
.db 106,93,114,93,106,101,114,101 ; E
.db 118,93,126,93,118,101,126,101 ; G
.db 130,93,138,93,130,101,138,101 ; A

.db 94,94,102,94,94,102,102,102 ; S
.db 106,94,114,94,106,102,114,102 ; E
.db 118,94,126,94,118,102,126,102 ; G
.db 130,94,138,94,130,102,138,102 ; A

.db 94,95,102,95,94,103,102,103 ; S
.db 106,95,114,95,106,103,114,103 ; E
.db 118,95,126,95,118,103,126,103 ; G
.db 130,95,138,95,130,103,138,103 ; A

.db 94,96,102,96,94,104,102,104 ; S
.db 106,96,114,96,106,104,114,104 ; E
.db 118,96,126,96,118,104,126,104 ; G
.db 130,96,138,96,130,104,138,104 ; A

.db 94,97,102,97,94,105,102,105 ; S
.db 106,97,114,97,106,105,114,105 ; E
.db 118,97,126,97,118,105,126,105 ; G
.db 130,97,138,97,130,105,138,105 ; A

.db 94,98,102,98,94,106,102,106 ; S
.db 106,98,114,98,106,106,114,106 ; E
.db 118,98,126,98,118,106,126,106 ; G
.db 130,98,138,98,130,106,138,106 ; A

.db 94,99,102,99,94,107,102,107 ; S
.db 106,99,114,99,106,107,114,107 ; E
.db 118,99,126,99,118,107,126,107 ; G
.db 130,99,138,99,130,107,138,107 ; A

.db 94,100,102,100,94,108,102,108 ; S
.db 106,100,114,100,106,108,114,108 ; E
.db 118,100,126,100,118,108,126,108 ; G
.db 130,100,138,100,130,108,138,108 ; A

.db 94,101,102,101,94,109,102,109 ; S
.db 106,101,114,101,106,109,114,109 ; E
.db 118,101,126,101,118,109,126,109 ; G
.db 130,101,138,101,130,109,138,109 ; A

.db 94,102,102,102,94,110,102,110 ; S
.db 106,102,114,102,106,110,114,110 ; E
.db 118,102,126,102,118,110,126,110 ; G
.db 130,102,138,102,130,110,138,110 ; A

.db 95,103,103,103,95,111,103,111 ; S
.db 107,103,115,103,107,111,115,111 ; E
.db 119,103,127,103,119,111,127,111 ; G
.db 131,103,139,103,131,111,139,111 ; A

.db 96,104,104,104,96,112,104,112 ; S
.db 108,104,116,104,108,112,116,112 ; E
.db 120,104,128,104,120,112,128,112 ; G
.db 132,104,140,104,132,112,140,112 ; A

.db 97,105,105,105,97,113,105,113 ; S
.db 109,105,117,105,109,113,117,113 ; E
.db 121,105,129,105,121,113,129,113 ; G
.db 133,105,141,105,133,113,141,113 ; A

.db 96,106,104,106,96,114,104,114 ; S
.db 108,106,116,106,108,114,116,114 ; E
.db 120,106,128,106,120,114,128,114 ; G
.db 132,106,140,106,132,114,140,114 ; A

.db 95,107,103,107,95,115,103,115 ; S
.db 107,107,115,107,107,115,115,115 ; E
.db 119,107,127,107,119,115,127,115 ; G
.db 131,107,139,107,131,115,139,115 ; A

.db 94,108,102,108,94,116,102,116 ; S
.db 106,108,114,108,106,116,114,116 ; E
.db 118,108,126,108,118,116,126,116 ; G
.db 130,108,138,108,130,116,138,116 ; A

.db 93,109,101,109,93,117,101,117 ; S
.db 105,109,113,109,105,117,113,117 ; E
.db 117,109,125,109,117,117,125,117 ; G
.db 129,109,137,109,129,117,137,117 ; A

.db 92,110,100,110,92,118,100,118 ; S
.db 104,110,112,110,104,118,112,118 ; E
.db 116,110,124,110,116,118,124,118 ; G
.db 128,110,136,110,128,118,136,118 ; A

.db 91,111,99,111,91,119,99,119 ; S
.db 103,111,111,111,103,119,111,119 ; E
.db 115,111,123,111,115,119,123,119 ; G
.db 127,111,135,111,127,119,135,119 ; A

.db 90,112,98,112,90,120,98,120 ; S
.db 102,112,110,112,102,120,110,120 ; E
.db 114,112,122,112,114,120,122,120 ; G
.db 126,112,134,112,126,120,134,120 ; A

.db 89,113,97,113,89,121,97,121 ; S
.db 101,113,109,113,101,121,109,121 ; E
.db 113,113,121,113,113,121,121,121 ; G
.db 125,113,133,113,125,121,133,121 ; A

.db 88,114,96,114,88,122,96,122 ; S
.db 100,114,108,114,100,122,108,122 ; E
.db 112,114,120,114,112,122,120,122 ; G
.db 124,114,132,114,124,122,132,122 ; A

.db 87,115,95,115,87,123,95,123 ; S
.db 99,115,107,115,99,123,107,123 ; E
.db 111,115,119,115,111,123,119,123 ; G
.db 123,115,131,115,123,123,131,123 ; A

.db 87,116,95,116,87,124,95,124 ; S
.db 99,116,107,116,99,124,107,124 ; E
.db 111,116,119,116,111,124,119,124 ; G
.db 123,116,131,116,123,124,131,124 ; A

.db 86,117,94,117,86,125,94,125 ; S
.db 98,117,106,117,98,125,106,125 ; E
.db 110,117,118,117,110,125,118,125 ; G
.db 122,117,130,117,122,125,130,125 ; A

.db 85,118,93,118,85,126,93,126 ; S
.db 97,118,105,118,97,126,105,126 ; E
.db 109,118,117,118,109,126,117,126 ; G
.db 121,118,129,118,121,126,129,126 ; A

.db 84,119,92,119,84,127,92,127 ; S
.db 96,119,104,119,96,127,104,127 ; E
.db 108,119,116,119,108,127,116,127 ; G
.db 120,119,128,119,120,127,128,127 ; A

.db 84,120,92,120,84,128,92,128 ; S
.db 96,120,104,120,96,128,104,128 ; E
.db 108,120,116,120,108,128,116,128 ; G
.db 120,120,128,120,120,128,128,128 ; A

.db 84,121,92,121,84,129,92,129 ; S
.db 96,121,104,121,96,129,104,129 ; E
.db 108,121,116,121,108,129,116,129 ; G
.db 120,121,128,121,120,129,128,129 ; A

.db 84,122,92,122,84,130,92,130 ; S
.db 96,122,104,122,96,130,104,130 ; E
.db 108,122,116,122,108,130,116,130 ; G
.db 120,122,128,122,120,130,128,130 ; A

.db 83,122,91,122,83,130,91,130 ; S
.db 95,122,103,122,95,130,103,130 ; E
.db 107,122,115,122,107,130,115,130 ; G
.db 119,122,127,122,119,130,127,130 ; A

.db 82,122,90,122,82,130,90,130 ; S
.db 94,122,102,122,94,130,102,130 ; E
.db 106,122,114,122,106,130,114,130 ; G
.db 118,122,126,122,118,130,126,130 ; A

.db 81,122,89,122,81,130,89,130 ; S
.db 93,122,101,122,93,130,101,130 ; E
.db 105,122,113,122,105,130,113,130 ; G
.db 117,122,125,122,117,130,125,130 ; A

.db 80,122,88,122,80,130,88,130 ; S
.db 92,122,100,122,92,130,100,130 ; E
.db 104,122,112,122,104,130,112,130 ; G
.db 116,122,124,122,116,130,124,130 ; A

.db 79,122,87,122,79,130,87,130 ; S
.db 91,122,99,122,91,130,99,130 ; E
.db 103,122,111,122,103,130,111,130 ; G
.db 115,122,123,122,115,130,123,130 ; A

.db 78,122,86,122,78,130,86,130 ; S
.db 90,122,98,122,90,130,98,130 ; E
.db 102,122,110,122,102,130,110,130 ; G
.db 114,122,122,122,114,130,122,130 ; A

.db 77,122,85,122,77,130,85,130 ; S
.db 89,122,97,122,89,130,97,130 ; E
.db 101,122,109,122,101,130,109,130 ; G
.db 113,122,121,122,113,130,121,130 ; A

.db 76,122,84,122,76,130,84,130 ; S
.db 88,122,96,122,88,130,96,130 ; E
.db 100,122,108,122,100,130,108,130 ; G
.db 112,122,120,122,112,130,120,130 ; A

.db 75,122,83,122,75,130,83,130 ; S
.db 87,122,95,122,87,130,95,130 ; E
.db 99,122,107,122,99,130,107,130 ; G
.db 111,122,119,122,111,130,119,130 ; A

.db 74,122,82,122,74,130,82,130 ; S
.db 86,122,94,122,86,130,94,130 ; E
.db 98,122,106,122,98,130,106,130 ; G
.db 110,122,118,122,110,130,118,130 ; A

.db 73,122,81,122,73,130,81,130 ; S
.db 85,122,93,122,85,130,93,130 ; E
.db 97,122,105,122,97,130,105,130 ; G
.db 109,122,117,122,109,130,117,130 ; A

.db 72,122,80,122,72,130,80,130 ; S
.db 84,122,92,122,84,130,92,130 ; E
.db 96,122,104,122,96,130,104,130 ; G
.db 108,122,116,122,108,130,116,130 ; A

.db 71,122,79,122,71,130,79,130 ; S
.db 83,122,91,122,83,130,91,130 ; E
.db 95,122,103,122,95,130,103,130 ; G
.db 107,122,115,122,107,130,115,130 ; A

.db 70,122,78,122,70,130,78,130 ; S
.db 82,122,90,122,82,130,90,130 ; E
.db 94,122,102,122,94,130,102,130 ; G
.db 106,122,114,122,106,130,114,130 ; A

.db 69,122,77,122,69,130,77,130 ; S
.db 81,122,89,122,81,130,89,130 ; E
.db 93,122,101,122,93,130,101,130 ; G
.db 105,122,113,122,105,130,113,130 ; A

.db 68,122,76,122,68,130,76,130 ; S
.db 80,122,88,122,80,130,88,130 ; E
.db 92,122,100,122,92,130,100,130 ; G
.db 104,122,112,122,104,130,112,130 ; A

.db 68,123,76,123,68,131,76,131 ; S
.db 80,123,88,123,80,131,88,131 ; E
.db 92,123,100,123,92,131,100,131 ; G
.db 104,123,112,123,104,131,112,131 ; A

.db 69,124,77,124,69,132,77,132 ; S
.db 81,124,89,124,81,132,89,132 ; E
.db 93,124,101,124,93,132,101,132 ; G
.db 105,124,113,124,105,132,113,132 ; A

.db 70,125,78,125,70,133,78,133 ; S
.db 82,125,90,125,82,133,90,133 ; E
.db 94,125,102,125,94,133,102,133 ; G
.db 106,125,114,125,106,133,114,133 ; A

.db 71,126,79,126,71,134,79,134 ; S
.db 83,126,91,126,83,134,91,134 ; E
.db 95,126,103,126,95,134,103,134 ; G
.db 107,126,115,126,107,134,115,134 ; A

.db 72,127,80,127,72,135,80,135 ; S
.db 84,127,92,127,84,135,92,135 ; E
.db 96,127,104,127,96,135,104,135 ; G
.db 108,127,116,127,108,135,116,135 ; A

.db 73,128,81,128,73,136,81,136 ; S
.db 85,128,93,128,85,136,93,136 ; E
.db 97,128,105,128,97,136,105,136 ; G
.db 109,128,117,128,109,136,117,136 ; A

.db 74,129,82,129,74,137,82,137 ; S
.db 86,129,94,129,86,137,94,137 ; E
.db 98,129,106,129,98,137,106,137 ; G
.db 110,129,118,129,110,137,118,137 ; A

.db 75,130,83,130,75,138,83,138 ; S
.db 87,130,95,130,87,138,95,138 ; E
.db 99,130,107,130,99,138,107,138 ; G
.db 111,130,119,130,111,138,119,138 ; A

.db 76,131,84,131,76,139,84,139 ; S
.db 88,131,96,131,88,139,96,139 ; E
.db 100,131,108,131,100,139,108,139 ; G
.db 112,131,120,131,112,139,120,139 ; A

.db 77,132,85,132,77,140,85,140 ; S
.db 89,132,97,132,89,140,97,140 ; E
.db 101,132,109,132,101,140,109,140 ; G
.db 113,132,121,132,113,140,121,140 ; A

.db 78,133,86,133,78,141,86,141 ; S
.db 90,133,98,133,90,141,98,141 ; E
.db 102,133,110,133,102,141,110,141 ; G
.db 114,133,122,133,114,141,122,141 ; A

.db 79,134,87,134,79,142,87,142 ; S
.db 91,134,99,134,91,142,99,142 ; E
.db 103,134,111,134,103,142,111,142 ; G
.db 115,134,123,134,115,142,123,142 ; A

.db 80,135,88,135,80,143,88,143 ; S
.db 92,135,100,135,92,143,100,143 ; E
.db 104,135,112,135,104,143,112,143 ; G
.db 116,135,124,135,116,143,124,143 ; A

.db 81,136,89,136,81,144,89,144 ; S
.db 93,136,101,136,93,144,101,144 ; E
.db 105,136,113,136,105,144,113,144 ; G
.db 117,136,125,136,117,144,125,144 ; A

.db 82,137,90,137,82,145,90,145 ; S
.db 94,137,102,137,94,145,102,145 ; E
.db 106,137,114,137,106,145,114,145 ; G
.db 118,137,126,137,118,145,126,145 ; A

.db 83,138,91,138,83,146,91,146 ; S
.db 95,138,103,138,95,146,103,146 ; E
.db 107,138,115,138,107,146,115,146 ; G
.db 119,138,127,138,119,146,127,146 ; A

.db 84,139,92,139,84,147,92,147 ; S
.db 96,139,104,139,96,147,104,147 ; E
.db 108,139,116,139,108,147,116,147 ; G
.db 120,139,128,139,120,147,128,147 ; A

.db 85,140,93,140,85,148,93,148 ; S
.db 97,140,105,140,97,148,105,148 ; E
.db 109,140,117,140,109,148,117,148 ; G
.db 121,140,129,140,121,148,129,148 ; A

.db 86,141,94,141,86,149,94,149 ; S
.db 98,141,106,141,98,149,106,149 ; E
.db 110,141,118,141,110,149,118,149 ; G
.db 122,141,130,141,122,149,130,149 ; A

.db 87,142,95,142,87,150,95,150 ; S
.db 99,142,107,142,99,150,107,150 ; E
.db 111,142,119,142,111,150,119,150 ; G
.db 123,142,131,142,123,150,131,150 ; A

.db 88,143,96,143,88,151,96,151 ; S
.db 100,143,108,143,100,151,108,151 ; E
.db 112,143,120,143,112,151,120,151 ; G
.db 124,143,132,143,124,151,132,151 ; A

.db 89,144,97,144,89,152,97,152 ; S
.db 101,144,109,144,101,152,109,152 ; E
.db 113,144,121,144,113,152,121,152 ; G
.db 125,144,133,144,125,152,133,152 ; A

.db 90,145,98,145,90,153,98,153 ; S
.db 102,145,110,145,102,153,110,153 ; E
.db 114,145,122,145,114,153,122,153 ; G
.db 126,145,134,145,126,153,134,153 ; A

.db 91,146,99,146,91,154,99,154 ; S
.db 103,146,111,146,103,154,111,154 ; E
.db 115,146,123,146,115,154,123,154 ; G
.db 127,146,135,146,127,154,135,154 ; A

.db 92,147,100,147,92,155,100,155 ; S
.db 104,147,112,147,104,155,112,155 ; E
.db 116,147,124,147,116,155,124,155 ; G
.db 128,147,136,147,128,155,136,155 ; A

.db 93,148,101,148,93,156,101,156 ; S
.db 105,148,113,148,105,156,113,156 ; E
.db 117,148,125,148,117,156,125,156 ; G
.db 129,148,137,148,129,156,137,156 ; A

.db 94,149,102,149,94,157,102,157 ; S
.db 106,149,114,149,106,157,114,157 ; E
.db 118,149,126,149,118,157,126,157 ; G
.db 130,149,138,149,130,157,138,157 ; A

.db 95,149,103,149,95,157,103,157 ; S
.db 107,149,115,149,107,157,115,157 ; E
.db 119,149,127,149,119,157,127,157 ; G
.db 131,149,139,149,131,157,139,157 ; A

.db 96,149,104,149,96,157,104,157 ; S
.db 108,149,116,149,108,157,116,157 ; E
.db 120,149,128,149,120,157,128,157 ; G
.db 132,149,140,149,132,157,140,157 ; A

.db 97,149,105,149,97,157,105,157 ; S
.db 109,149,117,149,109,157,117,157 ; E
.db 121,149,129,149,121,157,129,157 ; G
.db 133,149,141,149,133,157,141,157 ; A

.db 98,149,106,149,98,157,106,157 ; S
.db 110,149,118,149,110,157,118,157 ; E
.db 122,149,130,149,122,157,130,157 ; G
.db 134,149,142,149,134,157,142,157 ; A

.db 99,149,107,149,99,157,107,157 ; S
.db 111,149,119,149,111,157,119,157 ; E
.db 123,149,131,149,123,157,131,157 ; G
.db 135,149,143,149,135,157,143,157 ; A

.db 100,149,108,149,100,157,108,157 ; S
.db 112,149,120,149,112,157,120,157 ; E
.db 124,149,132,149,124,157,132,157 ; G
.db 136,149,144,149,136,157,144,157 ; A

.db 101,149,109,149,101,157,109,157 ; S
.db 113,149,121,149,113,157,121,157 ; E
.db 125,149,133,149,125,157,133,157 ; G
.db 137,149,145,149,137,157,145,157 ; A

.db 102,149,110,149,102,157,110,157 ; S
.db 114,149,122,149,114,157,122,157 ; E
.db 126,149,134,149,126,157,134,157 ; G
.db 138,149,146,149,138,157,146,157 ; A

.db 103,149,111,149,103,157,111,157 ; S
.db 115,149,123,149,115,157,123,157 ; E
.db 127,149,135,149,127,157,135,157 ; G
.db 139,149,147,149,139,157,147,157 ; A

.db 104,149,112,149,104,157,112,157 ; S
.db 116,149,124,149,116,157,124,157 ; E
.db 128,149,136,149,128,157,136,157 ; G
.db 140,149,148,149,140,157,148,157 ; A

.db 105,149,113,149,105,157,113,157 ; S
.db 117,149,125,149,117,157,125,157 ; E
.db 129,149,137,149,129,157,137,157 ; G
.db 141,149,149,149,141,157,149,157 ; A

.db 106,149,114,149,106,157,114,157 ; S
.db 118,149,126,149,118,157,126,157 ; E
.db 130,149,138,149,130,157,138,157 ; G
.db 142,149,150,149,142,157,150,157 ; A

.db 107,149,115,149,107,157,115,157 ; S
.db 119,149,127,149,119,157,127,157 ; E
.db 131,149,139,149,131,157,139,157 ; G
.db 143,149,151,149,143,157,151,157 ; A

.db 108,149,116,149,108,157,116,157 ; S
.db 120,149,128,149,120,157,128,157 ; E
.db 132,149,140,149,132,157,140,157 ; G
.db 144,149,152,149,144,157,152,157 ; A

.db 110,149,118,149,110,157,118,157 ; S
.db 122,149,130,149,122,157,130,157 ; E
.db 134,149,142,149,134,157,142,157 ; G
.db 146,149,154,149,146,157,154,157 ; A

.db 111,149,119,149,111,157,119,157 ; S
.db 123,149,131,149,123,157,131,157 ; E
.db 135,149,143,149,135,157,143,157 ; G
.db 147,149,155,149,147,157,155,157 ; A

.db 112,149,120,149,112,157,120,157 ; S
.db 124,149,132,149,124,157,132,157 ; E
.db 136,149,144,149,136,157,144,157 ; G
.db 148,149,156,149,148,157,156,157 ; A

.db 113,149,121,149,113,157,121,157 ; S
.db 125,149,133,149,125,157,133,157 ; E
.db 137,149,145,149,137,157,145,157 ; G
.db 149,149,157,149,149,157,157,157 ; A

.db 114,149,122,149,114,157,122,157 ; S
.db 126,149,134,149,126,157,134,157 ; E
.db 138,149,146,149,138,157,146,157 ; G
.db 150,149,158,149,150,157,158,157 ; A

.db 115,149,123,149,115,157,123,157 ; S
.db 127,149,135,149,127,157,135,157 ; E
.db 139,149,147,149,139,157,147,157 ; G
.db 151,149,159,149,151,157,159,157 ; A

.db 116,149,124,149,116,157,124,157 ; S
.db 128,149,136,149,128,157,136,157 ; E
.db 140,149,148,149,140,157,148,157 ; G
.db 152,149,160,149,152,157,160,157 ; A

.db 117,149,125,149,117,157,125,157 ; S
.db 129,149,137,149,129,157,137,157 ; E
.db 141,149,149,149,141,157,149,157 ; G
.db 153,149,161,149,153,157,161,157 ; A

.db 118,149,126,149,118,157,126,157 ; S
.db 130,149,138,149,130,157,138,157 ; E
.db 142,149,150,149,142,157,150,157 ; G
.db 154,149,162,149,154,157,162,157 ; A

.db 119,149,127,149,119,157,127,157 ; S
.db 131,149,139,149,131,157,139,157 ; E
.db 143,149,151,149,143,157,151,157 ; G
.db 155,149,163,149,155,157,163,157 ; A

.db 120,149,128,149,120,157,128,157 ; S
.db 132,149,140,149,132,157,140,157 ; E
.db 144,149,152,149,144,157,152,157 ; G
.db 156,149,164,149,156,157,164,157 ; A

.db 120,148,128,148,120,156,128,156 ; S
.db 132,148,140,148,132,156,140,156 ; E
.db 144,148,152,148,144,156,152,156 ; G
.db 156,148,164,148,156,156,164,156 ; A

.db 120,147,128,147,120,155,128,155 ; S
.db 132,147,140,147,132,155,140,155 ; E
.db 144,147,152,147,144,155,152,155 ; G
.db 156,147,164,147,156,155,164,155 ; A

.db 120,146,128,146,120,154,128,154 ; S
.db 132,146,140,146,132,154,140,154 ; E
.db 144,146,152,146,144,154,152,154 ; G
.db 156,146,164,146,156,154,164,154 ; A

.db 120,145,128,145,120,153,128,153 ; S
.db 132,145,140,145,132,153,140,153 ; E
.db 144,145,152,145,144,153,152,153 ; G
.db 156,145,164,145,156,153,164,153 ; A

.db 120,144,128,144,120,152,128,152 ; S
.db 132,144,140,144,132,152,140,152 ; E
.db 144,144,152,144,144,152,152,152 ; G
.db 156,144,164,144,156,152,164,152 ; A

.db 120,143,128,143,120,151,128,151 ; S
.db 132,143,140,143,132,151,140,151 ; E
.db 144,143,152,143,144,151,152,151 ; G
.db 156,143,164,143,156,151,164,151 ; A

.db 120,142,128,142,120,150,128,150 ; S
.db 132,142,140,142,132,150,140,150 ; E
.db 144,142,152,142,144,150,152,150 ; G
.db 156,142,164,142,156,150,164,150 ; A

.db 120,141,128,141,120,149,128,149 ; S
.db 132,141,140,141,132,149,140,149 ; E
.db 144,141,152,141,144,149,152,149 ; G
.db 156,141,164,141,156,149,164,149 ; A

.db 120,139,128,139,120,147,128,147 ; S
.db 132,139,140,139,132,147,140,147 ; E
.db 144,139,152,139,144,147,152,147 ; G
.db 156,139,164,139,156,147,164,147 ; A

.db 120,138,128,138,120,146,128,146 ; S
.db 132,138,140,138,132,146,140,146 ; E
.db 144,138,152,138,144,146,152,146 ; G
.db 156,138,164,138,156,146,164,146 ; A

.db 120,137,128,137,120,145,128,145 ; S
.db 132,137,140,137,132,145,140,145 ; E
.db 144,137,152,137,144,145,152,145 ; G
.db 156,137,164,137,156,145,164,145 ; A

.db 120,136,128,136,120,144,128,144 ; S
.db 132,136,140,136,132,144,140,144 ; E
.db 144,136,152,136,144,144,152,144 ; G
.db 156,136,164,136,156,144,164,144 ; A

.db 120,135,128,135,120,143,128,143 ; S
.db 132,135,140,135,132,143,140,143 ; E
.db 144,135,152,135,144,143,152,143 ; G
.db 156,135,164,135,156,143,164,143 ; A

.db 120,134,128,134,120,142,128,142 ; S
.db 132,134,140,134,132,142,140,142 ; E
.db 144,134,152,134,144,142,152,142 ; G
.db 156,134,164,134,156,142,164,142 ; A

.db 120,133,128,133,120,141,128,141 ; S
.db 132,133,140,133,132,141,140,141 ; E
.db 144,133,152,133,144,141,152,141 ; G
.db 156,133,164,133,156,141,164,141 ; A

.db 120,132,128,132,120,140,128,140 ; S
.db 132,132,140,132,132,140,140,140 ; E
.db 144,132,152,132,144,140,152,140 ; G
.db 156,132,164,132,156,140,164,140 ; A

.db 120,131,128,131,120,139,128,139 ; S
.db 132,131,140,131,132,139,140,139 ; E
.db 144,131,152,131,144,139,152,139 ; G
.db 156,131,164,131,156,139,164,139 ; A

.db 120,130,128,130,120,138,128,138 ; S
.db 132,130,140,130,132,138,140,138 ; E
.db 144,130,152,130,144,138,152,138 ; G
.db 156,130,164,130,156,138,164,138 ; A

.db 120,129,128,129,120,137,128,137 ; S
.db 132,129,140,129,132,137,140,137 ; E
.db 144,129,152,129,144,137,152,137 ; G
.db 156,129,164,129,156,137,164,137 ; A

.db 120,128,128,128,120,136,128,136 ; S
.db 132,128,140,128,132,136,140,136 ; E
.db 144,128,152,128,144,136,152,136 ; G
.db 156,128,164,128,156,136,164,136 ; A

.db 120,127,128,127,120,135,128,135 ; S
.db 132,127,140,127,132,135,140,135 ; E
.db 144,127,152,127,144,135,152,135 ; G
.db 156,127,164,127,156,135,164,135 ; A

.db 120,126,128,126,120,134,128,134 ; S
.db 132,126,140,126,132,134,140,134 ; E
.db 144,126,152,126,144,134,152,134 ; G
.db 156,126,164,126,156,134,164,134 ; A

.db 120,125,128,125,120,133,128,133 ; S
.db 132,125,140,125,132,133,140,133 ; E
.db 144,125,152,125,144,133,152,133 ; G
.db 156,125,164,125,156,133,164,133 ; A

.db 120,124,128,124,120,132,128,132 ; S
.db 132,124,140,124,132,132,140,132 ; E
.db 144,124,152,124,144,132,152,132 ; G
.db 156,124,164,124,156,132,164,132 ; A

.db 120,123,128,123,120,131,128,131 ; S
.db 132,123,140,123,132,131,140,131 ; E
.db 144,123,152,123,144,131,152,131 ; G
.db 156,123,164,123,156,131,164,131 ; A

.db 120,122,128,122,120,130,128,130 ; S
.db 132,122,140,122,132,130,140,130 ; E
.db 144,122,152,122,144,130,152,130 ; G
.db 156,122,164,122,156,130,164,130 ; A

.db 120,121,128,121,120,129,128,129 ; S
.db 132,121,140,121,132,129,140,129 ; E
.db 144,121,152,121,144,129,152,129 ; G
.db 156,121,164,121,156,129,164,129 ; A

.db 120,120,128,120,120,128,128,128 ; S
.db 132,120,140,120,132,128,140,128 ; E
.db 144,120,152,120,144,128,152,128 ; G
.db 156,120,164,120,156,128,164,128 ; A

.db 120,119,128,119,120,127,128,127 ; S
.db 132,119,140,119,132,127,140,127 ; E
.db 144,119,152,119,144,127,152,127 ; G
.db 156,119,164,119,156,127,164,127 ; A

.db 120,118,128,118,120,126,128,126 ; S
.db 132,118,140,118,132,126,140,126 ; E
.db 144,118,152,118,144,126,152,126 ; G
.db 156,118,164,118,156,126,164,126 ; A

.db 120,117,128,117,120,125,128,125 ; S
.db 132,117,140,117,132,125,140,125 ; E
.db 144,117,152,117,144,125,152,125 ; G
.db 156,117,164,117,156,125,164,125 ; A

.db 120,116,128,116,120,124,128,124 ; S
.db 132,116,140,116,132,124,140,124 ; E
.db 144,116,152,116,144,124,152,124 ; G
.db 156,116,164,116,156,124,164,124 ; A

.db 120,115,128,115,120,123,128,123 ; S
.db 132,115,140,115,132,123,140,123 ; E
.db 144,115,152,115,144,123,152,123 ; G
.db 156,115,164,115,156,123,164,123 ; A

.db 120,114,128,114,120,122,128,122 ; S
.db 132,114,140,114,132,122,140,122 ; E
.db 144,114,152,114,144,122,152,122 ; G
.db 156,114,164,114,156,122,164,122 ; A

.db 120,113,128,113,120,121,128,121 ; S
.db 132,113,140,113,132,121,140,121 ; E
.db 144,113,152,113,144,121,152,121 ; G
.db 156,113,164,113,156,121,164,121 ; A

.db 120,112,128,112,120,120,128,120 ; S
.db 132,112,140,112,132,120,140,120 ; E
.db 144,112,152,112,144,120,152,120 ; G
.db 156,112,164,112,156,120,164,120 ; A

.db 120,111,128,111,120,119,128,119 ; S
.db 132,111,140,111,132,119,140,119 ; E
.db 144,111,152,111,144,119,152,119 ; G
.db 156,111,164,111,156,119,164,119 ; A

.db 120,110,128,110,120,118,128,118 ; S
.db 132,110,140,110,132,118,140,118 ; E
.db 144,110,152,110,144,118,152,118 ; G
.db 156,110,164,110,156,118,164,118 ; A

.db 120,109,128,109,120,117,128,117 ; S
.db 132,109,140,109,132,117,140,117 ; E
.db 144,109,152,109,144,117,152,117 ; G
.db 156,109,164,109,156,117,164,117 ; A

.db 120,108,128,108,120,116,128,116 ; S
.db 132,108,140,108,132,116,140,116 ; E
.db 144,108,152,108,144,116,152,116 ; G
.db 156,108,164,108,156,116,164,116 ; A

.db 120,107,128,107,120,115,128,115 ; S
.db 132,107,140,107,132,115,140,115 ; E
.db 144,107,152,107,144,115,152,115 ; G
.db 156,107,164,107,156,115,164,115 ; A

.db 120,106,128,106,120,114,128,114 ; S
.db 132,106,140,106,132,114,140,114 ; E
.db 144,106,152,106,144,114,152,114 ; G
.db 156,106,164,106,156,114,164,114 ; A

.db 120,105,128,105,120,113,128,113 ; S
.db 132,105,140,105,132,113,140,113 ; E
.db 144,105,152,105,144,113,152,113 ; G
.db 156,105,164,105,156,113,164,113 ; A

.db 120,104,128,104,120,112,128,112 ; S
.db 132,104,140,104,132,112,140,112 ; E
.db 144,104,152,104,144,112,152,112 ; G
.db 156,104,164,104,156,112,164,112 ; A

.db 120,103,128,103,120,111,128,111 ; S
.db 132,103,140,103,132,111,140,111 ; E
.db 144,103,152,103,144,111,152,111 ; G
.db 156,103,164,103,156,111,164,111 ; A

.db 120,102,128,102,120,110,128,110 ; S
.db 132,102,140,102,132,110,140,110 ; E
.db 144,102,152,102,144,110,152,110 ; G
.db 156,102,164,102,156,110,164,110 ; A

.db 120,101,128,101,120,109,128,109 ; S
.db 132,101,140,101,132,109,140,109 ; E
.db 144,101,152,101,144,109,152,109 ; G
.db 156,101,164,101,156,109,164,109 ; A

.db 120,100,128,100,120,108,128,108 ; S
.db 132,100,140,100,132,108,140,108 ; E
.db 144,100,152,100,144,108,152,108 ; G
.db 156,100,164,100,156,108,164,108 ; A

.db 120,99,128,99,120,107,128,107 ; S
.db 132,99,140,99,132,107,140,107 ; E
.db 144,99,152,99,144,107,152,107 ; G
.db 156,99,164,99,156,107,164,107 ; A

.db 120,98,128,98,120,106,128,106 ; S
.db 132,98,140,98,132,106,140,106 ; E
.db 144,98,152,98,144,106,152,106 ; G
.db 156,98,164,98,156,106,164,106 ; A

.db 120,97,128,97,120,105,128,105 ; S
.db 132,97,140,97,132,105,140,105 ; E
.db 144,97,152,97,144,105,152,105 ; G
.db 156,97,164,97,156,105,164,105 ; A

.db 120,96,128,96,120,104,128,104 ; S
.db 132,96,140,96,132,104,140,104 ; E
.db 144,96,152,96,144,104,152,104 ; G
.db 156,96,164,96,156,104,164,104 ; A

.db 120,95,128,95,120,103,128,103 ; S
.db 132,95,140,95,132,103,140,103 ; E
.db 144,95,152,95,144,103,152,103 ; G
.db 156,95,164,95,156,103,164,103 ; A

.db 120,94,128,94,120,102,128,102 ; S
.db 132,94,140,94,132,102,140,102 ; E
.db 144,94,152,94,144,102,152,102 ; G
.db 156,94,164,94,156,102,164,102 ; A

.db 120,93,128,93,120,101,128,101 ; S
.db 132,93,140,93,132,101,140,101 ; E
.db 144,93,152,93,144,101,152,101 ; G
.db 156,93,164,93,156,101,164,101 ; A

.db 120,92,128,92,120,100,128,100 ; S
.db 132,92,140,92,132,100,140,100 ; E
.db 144,92,152,92,144,100,152,100 ; G
.db 156,92,164,92,156,100,164,100 ; A

.db 120,91,128,91,120,99,128,99 ; S
.db 132,91,140,91,132,99,140,99 ; E
.db 144,91,152,91,144,99,152,99 ; G
.db 156,91,164,91,156,99,164,99 ; A

.db 120,90,128,90,120,98,128,98 ; S
.db 132,90,140,90,132,98,140,98 ; E
.db 144,90,152,90,144,98,152,98 ; G
.db 156,90,164,90,156,98,164,98 ; A

.db 120,89,128,89,120,97,128,97 ; S
.db 132,89,140,89,132,97,140,97 ; E
.db 144,89,152,89,144,97,152,97 ; G
.db 156,89,164,89,156,97,164,97 ; A

.db 120,88,128,88,120,96,128,96 ; S
.db 132,88,140,88,132,96,140,96 ; E
.db 144,88,152,88,144,96,152,96 ; G
.db 156,88,164,88,156,96,164,96 ; A

.db 120,87,128,87,120,95,128,95 ; S
.db 132,87,140,87,132,95,140,95 ; E
.db 144,87,152,87,144,95,152,95 ; G
.db 156,87,164,87,156,95,164,95 ; A

.db 120,86,128,86,120,94,128,94 ; S
.db 132,86,140,86,132,94,140,94 ; E
.db 144,86,152,86,144,94,152,94 ; G
.db 156,86,164,86,156,94,164,94 ; A

.db 120,85,128,85,120,93,128,93 ; S
.db 132,85,140,85,132,93,140,93 ; E
.db 144,85,152,85,144,93,152,93 ; G
.db 156,85,164,85,156,93,164,93 ; A

.db 120,84,128,84,120,92,128,92 ; S
.db 132,84,140,84,132,92,140,92 ; E
.db 144,84,152,84,144,92,152,92 ; G
.db 156,84,164,84,156,92,164,92 ; A

.db 120,83,128,83,120,91,128,91 ; S
.db 132,83,140,83,132,91,140,91 ; E
.db 144,83,152,83,144,91,152,91 ; G
.db 156,83,164,83,156,91,164,91 ; A

.db 120,82,128,82,120,90,128,90 ; S
.db 132,82,140,82,132,90,140,90 ; E
.db 144,82,152,82,144,90,152,90 ; G
.db 156,82,164,82,156,90,164,90 ; A

.db 120,81,128,81,120,89,128,89 ; S
.db 132,81,140,81,132,89,140,89 ; E
.db 144,81,152,81,144,89,152,89 ; G
.db 156,81,164,81,156,89,164,89 ; A

.db 120,80,128,80,120,88,128,88 ; S
.db 132,80,140,80,132,88,140,88 ; E
.db 144,80,152,80,144,88,152,88 ; G
.db 156,80,164,80,156,88,164,88 ; A

.db 120,79,128,79,120,87,128,87 ; S
.db 132,79,140,79,132,87,140,87 ; E
.db 144,79,152,79,144,87,152,87 ; G
.db 156,79,164,79,156,87,164,87 ; A

.db 120,78,128,78,120,86,128,86 ; S
.db 132,78,140,78,132,86,140,86 ; E
.db 144,78,152,78,144,86,152,86 ; G
.db 156,78,164,78,156,86,164,86 ; A

.db 120,77,128,77,120,85,128,85 ; S
.db 132,77,140,77,132,85,140,85 ; E
.db 144,77,152,77,144,85,152,85 ; G
.db 156,77,164,77,156,85,164,85 ; A

.db 120,76,128,76,120,84,128,84 ; S
.db 132,76,140,76,132,84,140,84 ; E
.db 144,76,152,76,144,84,152,84 ; G
.db 156,76,164,76,156,84,164,84 ; A

.db 120,75,128,75,120,83,128,83 ; S
.db 132,75,140,75,132,83,140,83 ; E
.db 144,75,152,75,144,83,152,83 ; G
.db 156,75,164,75,156,83,164,83 ; A

.db 120,74,128,74,120,82,128,82 ; S
.db 132,74,140,74,132,82,140,82 ; E
.db 144,74,152,74,144,82,152,82 ; G
.db 156,74,164,74,156,82,164,82 ; A

.db 120,73,128,73,120,81,128,81 ; S
.db 132,73,140,73,132,81,140,81 ; E
.db 144,73,152,73,144,81,152,81 ; G
.db 156,73,164,73,156,81,164,81 ; A

.db 120,72,128,72,120,80,128,80 ; S
.db 132,72,140,72,132,80,140,80 ; E
.db 144,72,152,72,144,80,152,80 ; G
.db 156,72,164,72,156,80,164,80 ; A

.db 120,71,128,71,120,79,128,79 ; S
.db 132,71,140,71,132,79,140,79 ; E
.db 144,71,152,71,144,79,152,79 ; G
.db 156,71,164,71,156,79,164,79 ; A

.db 120,70,128,70,120,78,128,78 ; S
.db 132,70,140,70,132,78,140,78 ; E
.db 144,70,152,70,144,78,152,78 ; G
.db 156,70,164,70,156,78,164,78 ; A

.db 120,69,128,69,120,77,128,77 ; S
.db 132,69,140,69,132,77,140,77 ; E
.db 144,69,152,69,144,77,152,77 ; G
.db 156,69,164,69,156,77,164,77 ; A

.db 120,68,128,68,120,76,128,76 ; S
.db 132,68,140,68,132,76,140,76 ; E
.db 144,68,152,68,144,76,152,76 ; G
.db 156,68,164,68,156,76,164,76 ; A

.db 119,67,127,67,119,75,127,75 ; S
.db 131,67,139,67,131,75,139,75 ; E
.db 143,67,151,67,143,75,151,75 ; G
.db 155,67,163,67,155,75,163,75 ; A

.db 118,66,126,66,118,74,126,74 ; S
.db 130,66,138,66,130,74,138,74 ; E
.db 142,66,150,66,142,74,150,74 ; G
.db 154,66,162,66,154,74,162,74 ; A

.db 117,65,125,65,117,73,125,73 ; S
.db 129,65,137,65,129,73,137,73 ; E
.db 141,65,149,65,141,73,149,73 ; G
.db 153,65,161,65,153,73,161,73 ; A

.db 116,64,124,64,116,72,124,72 ; S
.db 128,64,136,64,128,72,136,72 ; E
.db 140,64,148,64,140,72,148,72 ; G
.db 152,64,160,64,152,72,160,72 ; A

.db 115,63,123,63,115,71,123,71 ; S
.db 127,63,135,63,127,71,135,71 ; E
.db 139,63,147,63,139,71,147,71 ; G
.db 151,63,159,63,151,71,159,71 ; A

.db 114,62,122,62,114,70,122,70 ; S
.db 126,62,134,62,126,70,134,70 ; E
.db 138,62,146,62,138,70,146,70 ; G
.db 150,62,158,62,150,70,158,70 ; A

.db 115,61,123,61,115,69,123,69 ; S
.db 127,61,135,61,127,69,135,69 ; E
.db 139,61,147,61,139,69,147,69 ; G
.db 151,61,159,61,151,69,159,69 ; A

.db 116,60,124,60,116,68,124,68 ; S
.db 128,60,136,60,128,68,136,68 ; E
.db 140,60,148,60,140,68,148,68 ; G
.db 152,60,160,60,152,68,160,68 ; A

.db 117,59,125,59,117,67,125,67 ; S
.db 129,59,137,59,129,67,137,67 ; E
.db 141,59,149,59,141,67,149,67 ; G
.db 153,59,161,59,153,67,161,67 ; A

.db 118,58,126,58,118,66,126,66 ; S
.db 130,58,138,58,130,66,138,66 ; E
.db 142,58,150,58,142,66,150,66 ; G
.db 154,58,162,58,154,66,162,66 ; A

.db 119,57,127,57,119,65,127,65 ; S
.db 131,57,139,57,131,65,139,65 ; E
.db 143,57,151,57,143,65,151,65 ; G
.db 155,57,163,57,155,65,163,65 ; A

.db 120,56,128,56,120,64,128,64 ; S
.db 132,56,140,56,132,64,140,64 ; E
.db 144,56,152,56,144,64,152,64 ; G
.db 156,56,164,56,156,64,164,64 ; A

.db 121,55,129,55,121,63,129,63 ; S
.db 133,55,141,55,133,63,141,63 ; E
.db 145,55,153,55,145,63,153,63 ; G
.db 157,55,165,55,157,63,165,63 ; A

.db 122,54,130,54,122,62,130,62 ; S
.db 134,54,142,54,134,62,142,62 ; E
.db 146,54,154,54,146,62,154,62 ; G
.db 158,54,166,54,158,62,166,62 ; A

.db 123,53,131,53,123,61,131,61 ; S
.db 135,53,143,53,135,61,143,61 ; E
.db 147,53,155,53,147,61,155,61 ; G
.db 159,53,167,53,159,61,167,61 ; A

.db 124,52,132,52,124,60,132,60 ; S
.db 136,52,144,52,136,60,144,60 ; E
.db 148,52,156,52,148,60,156,60 ; G
.db 160,52,168,52,160,60,168,60 ; A

.db 125,51,133,51,125,59,133,59 ; S
.db 137,51,145,51,137,59,145,59 ; E
.db 149,51,157,51,149,59,157,59 ; G
.db 161,51,169,51,161,59,169,59 ; A

.db 126,50,134,50,126,58,134,58 ; S
.db 138,50,146,50,138,58,146,58 ; E
.db 150,50,158,50,150,58,158,58 ; G
.db 162,50,170,50,162,58,170,58 ; A

.db 127,49,135,49,127,57,135,57 ; S
.db 139,49,147,49,139,57,147,57 ; E
.db 151,49,159,49,151,57,159,57 ; G
.db 163,49,171,49,163,57,171,57 ; A

.db 128,48,136,48,128,56,136,56 ; S
.db 140,48,148,48,140,56,148,56 ; E
.db 152,48,160,48,152,56,160,56 ; G
.db 164,48,172,48,164,56,172,56 ; A

.db 129,47,137,47,129,55,137,55 ; S
.db 141,47,149,47,141,55,149,55 ; E
.db 153,47,161,47,153,55,161,55 ; G
.db 165,47,173,47,165,55,173,55 ; A

.db 130,46,138,46,130,54,138,54 ; S
.db 142,46,150,46,142,54,150,54 ; E
.db 154,46,162,46,154,54,162,54 ; G
.db 166,46,174,46,166,54,174,54 ; A

.db 131,45,139,45,131,53,139,53 ; S
.db 143,45,151,45,143,53,151,53 ; E
.db 155,45,163,45,155,53,163,53 ; G
.db 167,45,175,45,167,53,175,53 ; A

.db 132,44,140,44,132,52,140,52 ; S
.db 144,44,152,44,144,52,152,52 ; E
.db 156,44,164,44,156,52,164,52 ; G
.db 168,44,176,44,168,52,176,52 ; A

.db 133,43,141,43,133,51,141,51 ; S
.db 145,43,153,43,145,51,153,51 ; E
.db 157,43,165,43,157,51,165,51 ; G
.db 169,43,177,43,169,51,177,51 ; A

.db 134,42,142,42,134,50,142,50 ; S
.db 146,42,154,42,146,50,154,50 ; E
.db 158,42,166,42,158,50,166,50 ; G
.db 170,42,178,42,170,50,178,50 ; A

.db 135,41,143,41,135,49,143,49 ; S
.db 147,41,155,41,147,49,155,49 ; E
.db 159,41,167,41,159,49,167,49 ; G
.db 171,41,179,41,171,49,179,49 ; A

.db 136,40,144,40,136,48,144,48 ; S
.db 148,40,156,40,148,48,156,48 ; E
.db 160,40,168,40,160,48,168,48 ; G
.db 172,40,180,40,172,48,180,48 ; A

.db 137,39,145,39,137,47,145,47 ; S
.db 149,39,157,39,149,47,157,47 ; E
.db 161,39,169,39,161,47,169,47 ; G
.db 173,39,181,39,173,47,181,47 ; A

.db 138,38,146,38,138,46,146,46 ; S
.db 150,38,158,38,150,46,158,46 ; E
.db 162,38,170,38,162,46,170,46 ; G
.db 174,38,182,38,174,46,182,46 ; A

.db 139,37,147,37,139,45,147,45 ; S
.db 151,37,159,37,151,45,159,45 ; E
.db 163,37,171,37,163,45,171,45 ; G
.db 175,37,183,37,175,45,183,45 ; A

.db 140,36,148,36,140,44,148,44 ; S
.db 152,36,160,36,152,44,160,44 ; E
.db 164,36,172,36,164,44,172,44 ; G
.db 176,36,184,36,176,44,184,44 ; A

.db 141,35,149,35,141,43,149,43 ; S
.db 153,35,161,35,153,43,161,43 ; E
.db 165,35,173,35,165,43,173,43 ; G
.db 177,35,185,35,177,43,185,43 ; A

.db 142,34,150,34,142,42,150,42 ; S
.db 154,34,162,34,154,42,162,42 ; E
.db 166,34,174,34,166,42,174,42 ; G
.db 178,34,186,34,178,42,186,42 ; A

.db 143,33,151,33,143,41,151,41 ; S
.db 155,33,163,33,155,41,163,41 ; E
.db 167,33,175,33,167,41,175,41 ; G
.db 179,33,187,33,179,41,187,41 ; A

.db 144,34,152,34,144,42,152,42 ; S
.db 156,34,164,34,156,42,164,42 ; E
.db 168,34,176,34,168,42,176,42 ; G
.db 180,34,188,34,180,42,188,42 ; A

.db 145,35,153,35,145,43,153,43 ; S
.db 157,35,165,35,157,43,165,43 ; E
.db 169,35,177,35,169,43,177,43 ; G
.db 181,35,189,35,181,43,189,43 ; A

.db 146,36,154,36,146,44,154,44 ; S
.db 158,36,166,36,158,44,166,44 ; E
.db 170,36,178,36,170,44,178,44 ; G
.db 182,36,190,36,182,44,190,44 ; A

.db 147,37,155,37,147,45,155,45 ; S
.db 159,37,167,37,159,45,167,45 ; E
.db 171,37,179,37,171,45,179,45 ; G
.db 183,37,191,37,183,45,191,45 ; A

.db 148,38,156,38,148,46,156,46 ; S
.db 160,38,168,38,160,46,168,46 ; E
.db 172,38,180,38,172,46,180,46 ; G
.db 184,38,192,38,184,46,192,46 ; A

.db 149,39,157,39,149,47,157,47 ; S
.db 161,39,169,39,161,47,169,47 ; E
.db 173,39,181,39,173,47,181,47 ; G
.db 185,39,193,39,185,47,193,47 ; A

.db 150,40,158,40,150,48,158,48 ; S
.db 162,40,170,40,162,48,170,48 ; E
.db 174,40,182,40,174,48,182,48 ; G
.db 186,40,194,40,186,48,194,48 ; A

.db 151,41,159,41,151,49,159,49 ; S
.db 163,41,171,41,163,49,171,49 ; E
.db 175,41,183,41,175,49,183,49 ; G
.db 187,41,195,41,187,49,195,49 ; A

.db 152,42,160,42,152,50,160,50 ; S
.db 164,42,172,42,164,50,172,50 ; E
.db 176,42,184,42,176,50,184,50 ; G
.db 188,42,196,42,188,50,196,50 ; A

.db 153,43,161,43,153,51,161,51 ; S
.db 165,43,173,43,165,51,173,51 ; E
.db 177,43,185,43,177,51,185,51 ; G
.db 189,43,197,43,189,51,197,51 ; A

.db 154,44,162,44,154,52,162,52 ; S
.db 166,44,174,44,166,52,174,52 ; E
.db 178,44,186,44,178,52,186,52 ; G
.db 190,44,198,44,190,52,198,52 ; A

.db 155,45,163,45,155,53,163,53 ; S
.db 167,45,175,45,167,53,175,53 ; E
.db 179,45,187,45,179,53,187,53 ; G
.db 191,45,199,45,191,53,199,53 ; A

.db 156,46,164,46,156,54,164,54 ; S
.db 168,46,176,46,168,54,176,54 ; E
.db 180,46,188,46,180,54,188,54 ; G
.db 192,46,200,46,192,54,200,54 ; A

.db 157,47,165,47,157,55,165,55 ; S
.db 169,47,177,47,169,55,177,55 ; E
.db 181,47,189,47,181,55,189,55 ; G
.db 193,47,201,47,193,55,201,55 ; A

.db 158,48,166,48,158,56,166,56 ; S
.db 170,48,178,48,170,56,178,56 ; E
.db 182,48,190,48,182,56,190,56 ; G
.db 194,48,202,48,194,56,202,56 ; A

.db 159,49,167,49,159,57,167,57 ; S
.db 171,49,179,49,171,57,179,57 ; E
.db 183,49,191,49,183,57,191,57 ; G
.db 195,49,203,49,195,57,203,57 ; A

.db 160,50,168,50,160,58,168,58 ; S
.db 172,50,180,50,172,58,180,58 ; E
.db 184,50,192,50,184,58,192,58 ; G
.db 196,50,204,50,196,58,204,58 ; A

.db 161,51,169,51,161,59,169,59 ; S
.db 173,51,181,51,173,59,181,59 ; E
.db 185,51,193,51,185,59,193,59 ; G
.db 197,51,205,51,197,59,205,59 ; A

.db 162,52,170,52,162,60,170,60 ; S
.db 174,52,182,52,174,60,182,60 ; E
.db 186,52,194,52,186,60,194,60 ; G
.db 198,52,206,52,198,60,206,60 ; A

.db 163,53,171,53,163,61,171,61 ; S
.db 175,53,183,53,175,61,183,61 ; E
.db 187,53,195,53,187,61,195,61 ; G
.db 199,53,207,53,199,61,207,61 ; A

.db 164,54,172,54,164,62,172,62 ; S
.db 176,54,184,54,176,62,184,62 ; E
.db 188,54,196,54,188,62,196,62 ; G
.db 200,54,208,54,200,62,208,62 ; A

.db 164,55,172,55,164,63,172,63 ; S
.db 176,55,184,55,176,63,184,63 ; E
.db 188,55,196,55,188,63,196,63 ; G
.db 200,55,208,55,200,63,208,63 ; A

.db 163,56,171,56,163,64,171,64 ; S
.db 175,56,183,56,175,64,183,64 ; E
.db 187,56,195,56,187,64,195,64 ; G
.db 199,56,207,56,199,64,207,64 ; A

.db 162,57,170,57,162,65,170,65 ; S
.db 174,57,182,57,174,65,182,65 ; E
.db 186,57,194,57,186,65,194,65 ; G
.db 198,57,206,57,198,65,206,65 ; A

.db 161,58,169,58,161,66,169,66 ; S
.db 173,58,181,58,173,66,181,66 ; E
.db 185,58,193,58,185,66,193,66 ; G
.db 197,58,205,58,197,66,205,66 ; A

.db 160,59,168,59,160,67,168,67 ; S
.db 172,59,180,59,172,67,180,67 ; E
.db 184,59,192,59,184,67,192,67 ; G
.db 196,59,204,59,196,67,204,67 ; A

.db 159,60,167,60,159,68,167,68 ; S
.db 171,60,179,60,171,68,179,68 ; E
.db 183,60,191,60,183,68,191,68 ; G
.db 195,60,203,60,195,68,203,68 ; A

.db 158,61,166,61,158,69,166,69 ; S
.db 170,61,178,61,170,69,178,69 ; E
.db 182,61,190,61,182,69,190,69 ; G
.db 194,61,202,61,194,69,202,69 ; A

.db 157,62,165,62,157,70,165,70 ; S
.db 169,62,177,62,169,70,177,70 ; E
.db 181,62,189,62,181,70,189,70 ; G
.db 193,62,201,62,193,70,201,70 ; A

.db 156,63,164,63,156,71,164,71 ; S
.db 168,63,176,63,168,71,176,71 ; E
.db 180,63,188,63,180,71,188,71 ; G
.db 192,63,200,63,192,71,200,71 ; A

.db 155,64,163,64,155,72,163,72 ; S
.db 167,64,175,64,167,72,175,72 ; E
.db 179,64,187,64,179,72,187,72 ; G
.db 191,64,199,64,191,72,199,72 ; A

.db 154,65,162,65,154,73,162,73 ; S
.db 166,65,174,65,166,73,174,73 ; E
.db 178,65,186,65,178,73,186,73 ; G
.db 190,65,198,65,190,73,198,73 ; A

.db 153,66,161,66,153,74,161,74 ; S
.db 165,66,173,66,165,74,173,74 ; E
.db 177,66,185,66,177,74,185,74 ; G
.db 189,66,197,66,189,74,197,74 ; A

.db 152,67,160,67,152,75,160,75 ; S
.db 164,67,172,67,164,75,172,75 ; E
.db 176,67,184,67,176,75,184,75 ; G
.db 188,67,196,67,188,75,196,75 ; A

.db 151,68,159,68,151,76,159,76 ; S
.db 163,68,171,68,163,76,171,76 ; E
.db 175,68,183,68,175,76,183,76 ; G
.db 187,68,195,68,187,76,195,76 ; A

.db 150,69,158,69,150,77,158,77 ; S
.db 162,69,170,69,162,77,170,77 ; E
.db 174,69,182,69,174,77,182,77 ; G
.db 186,69,194,69,186,77,194,77 ; A

.db 149,70,157,70,149,78,157,78 ; S
.db 161,70,169,70,161,78,169,78 ; E
.db 173,70,181,70,173,78,181,78 ; G
.db 185,70,193,70,185,78,193,78 ; A

.db 148,71,156,71,148,79,156,79 ; S
.db 160,71,168,71,160,79,168,79 ; E
.db 172,71,180,71,172,79,180,79 ; G
.db 184,71,192,71,184,79,192,79 ; A

.db 148,72,156,72,148,80,156,80 ; S
.db 160,72,168,72,160,80,168,80 ; E
.db 172,72,180,72,172,80,180,80 ; G
.db 184,72,192,72,184,80,192,80 ; A

.db 148,73,156,73,148,81,156,81 ; S
.db 160,73,168,73,160,81,168,81 ; E
.db 172,73,180,73,172,81,180,81 ; G
.db 184,73,192,73,184,81,192,81 ; A

.db 148,74,156,74,148,82,156,82 ; S
.db 160,74,168,74,160,82,168,82 ; E
.db 172,74,180,74,172,82,180,82 ; G
.db 184,74,192,74,184,82,192,82 ; A

.db 148,75,156,75,148,83,156,83 ; S
.db 160,75,168,75,160,83,168,83 ; E
.db 172,75,180,75,172,83,180,83 ; G
.db 184,75,192,75,184,83,192,83 ; A

.db 148,76,156,76,148,84,156,84 ; S
.db 160,76,168,76,160,84,168,84 ; E
.db 172,76,180,76,172,84,180,84 ; G
.db 184,76,192,76,184,84,192,84 ; A

.db 148,77,156,77,148,85,156,85 ; S
.db 160,77,168,77,160,85,168,85 ; E
.db 172,77,180,77,172,85,180,85 ; G
.db 184,77,192,77,184,85,192,85 ; A

.db 148,78,156,78,148,86,156,86 ; S
.db 160,78,168,78,160,86,168,86 ; E
.db 172,78,180,78,172,86,180,86 ; G
.db 184,78,192,78,184,86,192,86 ; A

.db 148,79,156,79,148,87,156,87 ; S
.db 160,79,168,79,160,87,168,87 ; E
.db 172,79,180,79,172,87,180,87 ; G
.db 184,79,192,79,184,87,192,87 ; A

.db 148,80,156,80,148,88,156,88 ; S
.db 160,80,168,80,160,88,168,88 ; E
.db 172,80,180,80,172,88,180,88 ; G
.db 184,80,192,80,184,88,192,88 ; A

.db 148,81,156,81,148,89,156,89 ; S
.db 160,81,168,81,160,89,168,89 ; E
.db 172,81,180,81,172,89,180,89 ; G
.db 184,81,192,81,184,89,192,89 ; A

.db 148,82,156,82,148,90,156,90 ; S
.db 160,82,168,82,160,90,168,90 ; E
.db 172,82,180,82,172,90,180,90 ; G
.db 184,82,192,82,184,90,192,90 ; A

.db 148,83,156,83,148,91,156,91 ; S
.db 160,83,168,83,160,91,168,91 ; E
.db 172,83,180,83,172,91,180,91 ; G
.db 184,83,192,83,184,91,192,91 ; A

.db 148,84,156,84,148,92,156,92 ; S
.db 160,84,168,84,160,92,168,92 ; E
.db 172,84,180,84,172,92,180,92 ; G
.db 184,84,192,84,184,92,192,92 ; A

.db 148,85,156,85,148,93,156,93 ; S
.db 160,85,168,85,160,93,168,93 ; E
.db 172,85,180,85,172,93,180,93 ; G
.db 184,85,192,85,184,93,192,93 ; A

.db 148,86,156,86,148,94,156,94 ; S
.db 160,86,168,86,160,94,168,94 ; E
.db 172,86,180,86,172,94,180,94 ; G
.db 184,86,192,86,184,94,192,94 ; A

.db 148,87,156,87,148,95,156,95 ; S
.db 160,87,168,87,160,95,168,95 ; E
.db 172,87,180,87,172,95,180,95 ; G
.db 184,87,192,87,184,95,192,95 ; A

.db 148,88,156,88,148,96,156,96 ; S
.db 160,88,168,88,160,96,168,96 ; E
.db 172,88,180,88,172,96,180,96 ; G
.db 184,88,192,88,184,96,192,96 ; A

.db 148,89,156,89,148,97,156,97 ; S
.db 160,89,168,89,160,97,168,97 ; E
.db 172,89,180,89,172,97,180,97 ; G
.db 184,89,192,89,184,97,192,97 ; A

.db 148,90,156,90,148,98,156,98 ; S
.db 160,90,168,90,160,98,168,98 ; E
.db 172,90,180,90,172,98,180,98 ; G
.db 184,90,192,90,184,98,192,98 ; A

.db 148,91,156,91,148,99,156,99 ; S
.db 160,91,168,91,160,99,168,99 ; E
.db 172,91,180,91,172,99,180,99 ; G
.db 184,91,192,91,184,99,192,99 ; A

.db 148,92,156,92,148,100,156,100 ; S
.db 160,92,168,92,160,100,168,100 ; E
.db 172,92,180,92,172,100,180,100 ; G
.db 184,92,192,92,184,100,192,100 ; A

.db 148,93,156,93,148,101,156,101 ; S
.db 160,93,168,93,160,101,168,101 ; E
.db 172,93,180,93,172,101,180,101 ; G
.db 184,93,192,93,184,101,192,101 ; A

.db 148,94,156,94,148,102,156,102 ; S
.db 160,94,168,94,160,102,168,102 ; E
.db 172,94,180,94,172,102,180,102 ; G
.db 184,94,192,94,184,102,192,102 ; A

.db 148,95,156,95,148,103,156,103 ; S
.db 160,95,168,95,160,103,168,103 ; E
.db 172,95,180,95,172,103,180,103 ; G
.db 184,95,192,95,184,103,192,103 ; A

.db 148,96,156,96,148,104,156,104 ; S
.db 160,96,168,96,160,104,168,104 ; E
.db 172,96,180,96,172,104,180,104 ; G
.db 184,96,192,96,184,104,192,104 ; A

.db 148,97,156,97,148,105,156,105 ; S
.db 160,97,168,97,160,105,168,105 ; E
.db 172,97,180,97,172,105,180,105 ; G
.db 184,97,192,97,184,105,192,105 ; A

.db 148,98,156,98,148,106,156,106 ; S
.db 160,98,168,98,160,106,168,106 ; E
.db 172,98,180,98,172,106,180,106 ; G
.db 184,98,192,98,184,106,192,106 ; A

.db 148,99,156,99,148,107,156,107 ; S
.db 160,99,168,99,160,107,168,107 ; E
.db 172,99,180,99,172,107,180,107 ; G
.db 184,99,192,99,184,107,192,107 ; A

.db 148,100,156,100,148,108,156,108 ; S
.db 160,100,168,100,160,108,168,108 ; E
.db 172,100,180,100,172,108,180,108 ; G
.db 184,100,192,100,184,108,192,108 ; A

.db 148,101,156,101,148,109,156,109 ; S
.db 160,101,168,101,160,109,168,109 ; E
.db 172,101,180,101,172,109,180,109 ; G
.db 184,101,192,101,184,109,192,109 ; A

.db 148,102,156,102,148,110,156,110 ; S
.db 160,102,168,102,160,110,168,110 ; E
.db 172,102,180,102,172,110,180,110 ; G
.db 184,102,192,102,184,110,192,110 ; A

.db 148,103,156,103,148,111,156,111 ; S
.db 160,103,168,103,160,111,168,111 ; E
.db 172,103,180,103,172,111,180,111 ; G
.db 184,103,192,103,184,111,192,111 ; A

.db 148,104,156,104,148,112,156,112 ; S
.db 160,104,168,104,160,112,168,112 ; E
.db 172,104,180,104,172,112,180,112 ; G
.db 184,104,192,104,184,112,192,112 ; A

.db 148,105,156,105,148,113,156,113 ; S
.db 160,105,168,105,160,113,168,113 ; E
.db 172,105,180,105,172,113,180,113 ; G
.db 184,105,192,105,184,113,192,113 ; A

.db 148,106,156,106,148,114,156,114 ; S
.db 160,106,168,106,160,114,168,114 ; E
.db 172,106,180,106,172,114,180,114 ; G
.db 184,106,192,106,184,114,192,114 ; A

.db 148,107,156,107,148,115,156,115 ; S
.db 160,107,168,107,160,115,168,115 ; E
.db 172,107,180,107,172,115,180,115 ; G
.db 184,107,192,107,184,115,192,115 ; A

.db 148,108,156,108,148,116,156,116 ; S
.db 160,108,168,108,160,116,168,116 ; E
.db 172,108,180,108,172,116,180,116 ; G
.db 184,108,192,108,184,116,192,116 ; A

.db 148,109,156,109,148,117,156,117 ; S
.db 160,109,168,109,160,117,168,117 ; E
.db 172,109,180,109,172,117,180,117 ; G
.db 184,109,192,109,184,117,192,117 ; A

.db 148,110,156,110,148,118,156,118 ; S
.db 160,110,168,110,160,118,168,118 ; E
.db 172,110,180,110,172,118,180,118 ; G
.db 184,110,192,110,184,118,192,118 ; A

.db 148,111,156,111,148,119,156,119 ; S
.db 160,111,168,111,160,119,168,119 ; E
.db 172,111,180,111,172,119,180,119 ; G
.db 184,111,192,111,184,119,192,119 ; A

.db 148,112,156,112,148,120,156,120 ; S
.db 160,112,168,112,160,120,168,120 ; E
.db 172,112,180,112,172,120,180,120 ; G
.db 184,112,192,112,184,120,192,120 ; A

.db 148,113,156,113,148,121,156,121 ; S
.db 160,113,168,113,160,121,168,121 ; E
.db 172,113,180,113,172,121,180,121 ; G
.db 184,113,192,113,184,121,192,121 ; A

.db 148,115,156,115,148,123,156,123 ; S
.db 160,115,168,115,160,123,168,123 ; E
.db 172,115,180,115,172,123,180,123 ; G
.db 184,115,192,115,184,123,192,123 ; A

.db 148,115,156,115,148,123,156,123 ; S
.db 160,115,168,115,160,123,168,123 ; E
.db 172,115,180,115,172,123,180,123 ; G
.db 184,115,192,115,184,123,192,123 ; A

.db 148,116,156,116,148,124,156,124 ; S
.db 160,116,168,116,160,124,168,124 ; E
.db 172,116,180,116,172,124,180,124 ; G
.db 184,116,192,116,184,124,192,124 ; A

.db 148,118,156,118,148,126,156,126 ; S
.db 160,118,168,118,160,126,168,126 ; E
.db 172,118,180,118,172,126,180,126 ; G
.db 184,118,192,118,184,126,192,126 ; A

.db 148,118,156,118,148,126,156,126 ; S
.db 160,118,168,118,160,126,168,126 ; E
.db 172,118,180,118,172,126,180,126 ; G
.db 184,118,192,118,184,126,192,126 ; A

.db 148,119,156,119,148,127,156,127 ; S
.db 160,119,168,119,160,127,168,127 ; E
.db 172,119,180,119,172,127,180,127 ; G
.db 184,119,192,119,184,127,192,127 ; A

.db 148,120,156,120,148,128,156,128 ; S
.db 160,120,168,120,160,128,168,128 ; E
.db 172,120,180,120,172,128,180,128 ; G
.db 184,120,192,120,184,128,192,128 ; A

.db 148,121,156,121,148,129,156,129 ; S
.db 160,121,168,121,160,129,168,129 ; E
.db 172,121,180,121,172,129,180,129 ; G
.db 184,121,192,121,184,129,192,129 ; A

.db 148,122,156,122,148,130,156,130 ; S
.db 160,122,168,122,160,130,168,130 ; E
.db 172,122,180,122,172,130,180,130 ; G
.db 184,122,192,122,184,130,192,130 ; A

.db 148,123,156,123,148,131,156,131 ; S
.db 160,123,168,123,160,131,168,131 ; E
.db 172,123,180,123,172,131,180,131 ; G
.db 184,123,192,123,184,131,192,131 ; A

.db 148,124,156,124,148,132,156,132 ; S
.db 160,124,168,124,160,132,168,132 ; E
.db 172,124,180,124,172,132,180,132 ; G
.db 184,124,192,124,184,132,192,132 ; A

.db 148,125,156,125,148,133,156,133 ; S
.db 160,125,168,125,160,133,168,133 ; E
.db 172,125,180,125,172,133,180,133 ; G
.db 184,125,192,125,184,133,192,133 ; A

.db 148,126,156,126,148,134,156,134 ; S
.db 160,126,168,126,160,134,168,134 ; E
.db 172,126,180,126,172,134,180,134 ; G
.db 184,126,192,126,184,134,192,134 ; A

.db 148,127,156,127,148,135,156,135 ; S
.db 160,127,168,127,160,135,168,135 ; E
.db 172,127,180,127,172,135,180,135 ; G
.db 184,127,192,127,184,135,192,135 ; A

.db 148,128,156,128,148,136,156,136 ; S
.db 160,128,168,128,160,136,168,136 ; E
.db 172,128,180,128,172,136,180,136 ; G
.db 184,128,192,128,184,136,192,136 ; A

.db 148,129,156,129,148,137,156,137 ; S
.db 160,129,168,129,160,137,168,137 ; E
.db 172,129,180,129,172,137,180,137 ; G
.db 184,129,192,129,184,137,192,137 ; A

.db 148,130,156,130,148,138,156,138 ; S
.db 160,130,168,130,160,138,168,138 ; E
.db 172,130,180,130,172,138,180,138 ; G
.db 184,130,192,130,184,138,192,138 ; A

.db 148,131,156,131,148,139,156,139 ; S
.db 160,131,168,131,160,139,168,139 ; E
.db 172,131,180,131,172,139,180,139 ; G
.db 184,131,192,131,184,139,192,139 ; A

.db 147,132,155,132,147,140,155,140 ; S
.db 159,132,167,132,159,140,167,140 ; E
.db 171,132,179,132,171,140,179,140 ; G
.db 183,132,191,132,183,140,191,140 ; A

.db 146,133,154,133,146,141,154,141 ; S
.db 158,133,166,133,158,141,166,141 ; E
.db 170,133,178,133,170,141,178,141 ; G
.db 182,133,190,133,182,141,190,141 ; A

.db 145,134,153,134,145,142,153,142 ; S
.db 157,134,165,134,157,142,165,142 ; E
.db 169,134,177,134,169,142,177,142 ; G
.db 181,134,189,134,181,142,189,142 ; A

.db 144,135,152,135,144,143,152,143 ; S
.db 156,135,164,135,156,143,164,143 ; E
.db 168,135,176,135,168,143,176,143 ; G
.db 180,135,188,135,180,143,188,143 ; A

.db 143,136,151,136,143,144,151,144 ; S
.db 155,136,163,136,155,144,163,144 ; E
.db 167,136,175,136,167,144,175,144 ; G
.db 179,136,187,136,179,144,187,144 ; A

.db 142,137,150,137,142,145,150,145 ; S
.db 154,137,162,137,154,145,162,145 ; E
.db 166,137,174,137,166,145,174,145 ; G
.db 178,137,186,137,178,145,186,145 ; A

.db 141,138,149,138,141,146,149,146 ; S
.db 153,138,161,138,153,146,161,146 ; E
.db 165,138,173,138,165,146,173,146 ; G
.db 177,138,185,138,177,146,185,146 ; A

.db 140,139,148,139,140,147,148,147 ; S
.db 152,139,160,139,152,147,160,147 ; E
.db 164,139,172,139,164,147,172,147 ; G
.db 176,139,184,139,176,147,184,147 ; A

.db 139,139,147,139,139,147,147,147 ; S
.db 151,139,159,139,151,147,159,147 ; E
.db 163,139,171,139,163,147,171,147 ; G
.db 175,139,183,139,175,147,183,147 ; A

.db 138,139,146,139,138,147,146,147 ; S
.db 150,139,158,139,150,147,158,147 ; E
.db 162,139,170,139,162,147,170,147 ; G
.db 174,139,182,139,174,147,182,147 ; A

.db 137,139,145,139,137,147,145,147 ; S
.db 149,139,157,139,149,147,157,147 ; E
.db 161,139,169,139,161,147,169,147 ; G
.db 173,139,181,139,173,147,181,147 ; A

.db 136,139,144,139,136,147,144,147 ; S
.db 148,139,156,139,148,147,156,147 ; E
.db 160,139,168,139,160,147,168,147 ; G
.db 172,139,180,139,172,147,180,147 ; A

.db 135,139,143,139,135,147,143,147 ; S
.db 147,139,155,139,147,147,155,147 ; E
.db 159,139,167,139,159,147,167,147 ; G
.db 171,139,179,139,171,147,179,147 ; A

.db 134,139,142,139,134,147,142,147 ; S
.db 146,139,154,139,146,147,154,147 ; E
.db 158,139,166,139,158,147,166,147 ; G
.db 170,139,178,139,170,147,178,147 ; A

.db 133,139,141,139,133,147,141,147 ; S
.db 145,139,153,139,145,147,153,147 ; E
.db 157,139,165,139,157,147,165,147 ; G
.db 169,139,177,139,169,147,177,147 ; A

.db 132,139,140,139,132,147,140,147 ; S
.db 144,139,152,139,144,147,152,147 ; E
.db 156,139,164,139,156,147,164,147 ; G
.db 168,139,176,139,168,147,176,147 ; A

.db 131,139,139,139,131,147,139,147 ; S
.db 143,139,151,139,143,147,151,147 ; E
.db 155,139,163,139,155,147,163,147 ; G
.db 167,139,175,139,167,147,175,147 ; A

.db 130,139,138,139,130,147,138,147 ; S
.db 142,139,150,139,142,147,150,147 ; E
.db 154,139,162,139,154,147,162,147 ; G
.db 166,139,174,139,166,147,174,147 ; A

.db 129,139,137,139,129,147,137,147 ; S
.db 141,139,149,139,141,147,149,147 ; E
.db 153,139,161,139,153,147,161,147 ; G
.db 165,139,173,139,165,147,173,147 ; A

.db 128,139,136,139,128,147,136,147 ; S
.db 140,139,148,139,140,147,148,147 ; E
.db 152,139,160,139,152,147,160,147 ; G
.db 164,139,172,139,164,147,172,147 ; A

.db 127,139,135,139,127,147,135,147 ; S
.db 139,139,147,139,139,147,147,147 ; E
.db 151,139,159,139,151,147,159,147 ; G
.db 163,139,171,139,163,147,171,147 ; A

.db 126,139,134,139,126,147,134,147 ; S
.db 138,139,146,139,138,147,146,147 ; E
.db 150,139,158,139,150,147,158,147 ; G
.db 162,139,170,139,162,147,170,147 ; A

.db 125,139,133,139,125,147,133,147 ; S
.db 137,139,145,139,137,147,145,147 ; E
.db 149,139,157,139,149,147,157,147 ; G
.db 161,139,169,139,161,147,169,147 ; A

.db 124,139,132,139,124,147,132,147 ; S
.db 136,139,144,139,136,147,144,147 ; E
.db 148,139,156,139,148,147,156,147 ; G
.db 160,139,168,139,160,147,168,147 ; A

.db 123,139,131,139,123,147,131,147 ; S
.db 135,139,143,139,135,147,143,147 ; E
.db 147,139,155,139,147,147,155,147 ; G
.db 159,139,167,139,159,147,167,147 ; A

.db 122,139,130,139,122,147,130,147 ; S
.db 134,139,142,139,134,147,142,147 ; E
.db 146,139,154,139,146,147,154,147 ; G
.db 158,139,166,139,158,147,166,147 ; A

.db 121,139,129,139,121,147,129,147 ; S
.db 133,139,141,139,133,147,141,147 ; E
.db 145,139,153,139,145,147,153,147 ; G
.db 157,139,165,139,157,147,165,147 ; A

.db 120,139,128,139,120,147,128,147 ; S
.db 132,139,140,139,132,147,140,147 ; E
.db 144,139,152,139,144,147,152,147 ; G
.db 156,139,164,139,156,147,164,147 ; A

Sprites_Move_Table_End: .db 16
